@@ -25,7 +25,7 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '3.12.1'
+version = '4.0.0'
 nightbuild = ''
 
 
@@ -84,6 +84,7 @@ main={
     'lastSeqDir': '',
     'errorUnits': 'Da',
     'printQuality': 5,
+    'reverseScrolling': 0,
     'macListCtrlGeneric': 1,
     'peaklistColumns': ['mz', 'int', 'rel', 'sn', 'z', 'fwhm', 'resol'],
     'donate': '',
@@ -223,7 +224,7 @@ processing={
         'isotopeShift': 0.0,
         'removeIsotopes': 1,
         'removeUnknown': 1,
-        'labelEnvelope': 'monoisotopic',
+        'labelEnvelope': '1st',
         'envelopeIntensity': 'maximum',
         'setAsMonoisotopic': 0,
     },
@@ -243,6 +244,9 @@ calibration={
 }
 
 sequence={
+    'editor':{
+        'gridSize': 20,
+    },
     'digest':{
         'maxMods': 1,
         'maxCharge': 1,
@@ -253,17 +257,22 @@ sequence={
         'highMass': 5000,
         'retainPos': 0,
         'allowMods': 0,
-        'listFormat': 'b.S.a [m]',
-        'matchFormat': '[r] b.S.a [m]',
+        'listTemplateAmino': 'b.S.a [m]',
+        'listTemplateCustom': 'b . [ S ] . a [m]',
+        'matchTemplateAmino': 'h b.S.a [m]',
+        'matchTemplateCustom': ' h b . [ S ] . a [m]',
     },
     'fragment':{
         'maxMods': 1,
         'maxCharge': 1,
         'massType': 1,
         'fragments': ['a','b','y','-NH3','-H2O'],
+        'maxLosses': 2,
         'filterFragments': 1,
-        'listFormat': 'b.S.a [m]',
-        'matchFormat': 'f [r] [m]',
+        'listTemplateAmino': 'b.S.a [m]',
+        'listTemplateCustom': 'b . [ S ] . a [m]',
+        'matchTemplateAmino': 'f h [m]',
+        'matchTemplateCustom': 'f h [m]',
     },
     'search':{
         'mass': 0,
@@ -275,7 +284,8 @@ sequence={
         'tolerance': 0.2,
         'units': 'Da',
         'retainPos': 0,
-        'listFormat': 'b.S.a [m]',
+        'listTemplateAmino': 'b.S.a [m]',
+        'listTemplateCustom': 'b . [ S ] . a [m]',
     },
 }
 
@@ -323,6 +333,19 @@ generator={
     'showFlipped': 0,
 }
 
+envfit={
+    'loss': 'H',
+    'gain': 'H{2}',
+    'fit': 'spectrum',
+    'scaleMin': 0,
+    'scaleMax': 10,
+    'charge': 1,
+    'fwhm': 0.01,
+    'forceFwhm': 0,
+    'autoAlign': 1,
+    'relThreshold': 0.05,
+}
+
 mascot={
     'common':{
         'title':'',
@@ -641,6 +664,10 @@ def loadConfig(path=os.path.join(confdir, 'config.xml')):
     sequenceTags = document.getElementsByTagName('sequence')
     if sequenceTags:
         
+        editorTags = sequenceTags[0].getElementsByTagName('editor')
+        if editorTags:
+            _getParams(editorTags[0], sequence['editor'])
+        
         digestTags = sequenceTags[0].getElementsByTagName('digest')
         if digestTags:
             _getParams(digestTags[0], sequence['digest'])
@@ -684,6 +711,11 @@ def loadConfig(path=os.path.join(confdir, 'config.xml')):
     if generatorTags:
         _getParams(generatorTags[0], generator)
     
+    # envelope fit
+    envfitTags = document.getElementsByTagName('envfit')
+    if envfitTags:
+        _getParams(envfitTags[0], envfit)
+    
     # mascot
     mascotTags = document.getElementsByTagName('mascot')
     if mascotTags:
@@ -770,6 +802,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="documentsHeight" value="%d" type="int" />\n' % (main['documentsHeight'])
     buff += '    <param name="peaklistWidth" value="%d" type="int" />\n' % (main['peaklistWidth'])
     buff += '    <param name="peaklistHeight" value="%d" type="int" />\n' % (main['peaklistHeight'])
+    buff += '    <param name="reverseScrolling" value="%d" type="int" />\n' % (bool(main['reverseScrolling']))
     buff += '    <param name="macListCtrlGeneric" value="%d" type="int" />\n' % (bool(main['macListCtrlGeneric']))
     buff += '    <param name="peaklistColumns" value="%s" type="str" />\n' % (';'.join(main['peaklistColumns']))
     buff += '    <param name="mzDigits" value="%d" type="int" />\n' % (main['mzDigits'])
@@ -916,6 +949,9 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     
     # sequence
     buff += '  <sequence>\n'
+    buff += '    <editor>\n'
+    buff += '      <param name="gridSize" value="%d" type="int" />\n' % (sequence['editor']['gridSize'])
+    buff += '    </editor>\n'
     buff += '    <digest>\n'
     buff += '      <param name="maxMods" value="%d" type="int" />\n' % (sequence['digest']['maxMods'])
     buff += '      <param name="maxCharge" value="%d" type="int" />\n' % (sequence['digest']['maxCharge'])
@@ -926,17 +962,14 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '      <param name="highMass" value="%d" type="int" />\n' % (sequence['digest']['highMass'])
     buff += '      <param name="retainPos" value="%d" type="int" />\n' % (bool(sequence['digest']['retainPos']))
     buff += '      <param name="allowMods" value="%d" type="int" />\n' % (bool(sequence['digest']['allowMods']))
-    buff += '      <param name="listFormat" value="%s" type="str" />\n' % (sequence['digest']['listFormat'])
-    buff += '      <param name="matchFormat" value="%s" type="str" />\n' % (sequence['digest']['matchFormat'])
     buff += '    </digest>\n'
     buff += '    <fragment>\n'
     buff += '      <param name="maxMods" value="%d" type="int" />\n' % (sequence['fragment']['maxMods'])
     buff += '      <param name="maxCharge" value="%d" type="int" />\n' % (sequence['fragment']['maxCharge'])
     buff += '      <param name="massType" value="%d" type="int" />\n' % (sequence['fragment']['massType'])
     buff += '      <param name="fragments" value="%s" type="str" />\n' % (';'.join(sequence['fragment']['fragments']))
+    buff += '      <param name="maxLosses" value="%d" type="int" />\n' % (sequence['fragment']['maxLosses'])
     buff += '      <param name="filterFragments" value="%d" type="int" />\n' % (bool(sequence['fragment']['filterFragments']))
-    buff += '      <param name="listFormat" value="%s" type="str" />\n' % (sequence['fragment']['listFormat'])
-    buff += '      <param name="matchFormat" value="%s" type="str" />\n' % (sequence['fragment']['matchFormat'])
     buff += '    </fragment>\n'
     buff += '    <search>\n'
     buff += '      <param name="maxMods" value="%d" type="int" />\n' % (sequence['search']['maxMods'])
@@ -947,7 +980,6 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '      <param name="tolerance" value="%f" type="float" />\n' % (sequence['search']['tolerance'])
     buff += '      <param name="units" value="%s" type="str" />\n' % (sequence['search']['units'])
     buff += '      <param name="retainPos" value="%d" type="int" />\n' % (bool(sequence['search']['retainPos']))
-    buff += '      <param name="listFormat" value="%s" type="str" />\n' % (sequence['search']['listFormat'])
     buff += '    </search>\n'
     buff += '  </sequence>\n\n'
     
@@ -993,6 +1025,15 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="showOverlay" value="%d" type="int" />\n' % (bool(generator['showOverlay']))
     buff += '  </generator>\n\n'
     
+    # envelope fit
+    buff += '  <envfit>\n'
+    buff += '    <param name="fit" value="%s" type="str" />\n' % (envfit['fit'])
+    buff += '    <param name="fwhm" value="%f" type="float" />\n' % (envfit['fwhm'])
+    buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(envfit['forceFwhm']))
+    buff += '    <param name="autoAlign" value="%d" type="int" />\n' % (bool(envfit['autoAlign']))
+    buff += '    <param name="relThreshold" value="%f" type="float" />\n' % (envfit['relThreshold'])
+    buff += '  </envfit>\n\n'
+    
     # mascot
     buff += '  <mascot>\n'
     buff += '    <common>\n'
