@@ -142,7 +142,7 @@ class dlgCompoundsEditor(wx.Dialog):
         self.itemDescription_value = wx.TextCtrl(self, -1, "", size=(250, -1))
         
         itemFormula_label = wx.StaticText(self, -1, "Formula:")
-        self.itemFormula_value = wx.TextCtrl(self, -1, "", size=(250, -1))
+        self.itemFormula_value = mwx.formulaCtrl(self, -1, "", size=(250, -1))
         self.itemFormula_value.Bind(wx.EVT_TEXT, self.onFormulaEdited)
         
         itemMoMass_label = wx.StaticText(self, -1, "Mo. mass:")
@@ -212,7 +212,7 @@ class dlgCompoundsEditor(wx.Dialog):
         # update item editor
         self.itemName_value.SetValue(name)
         self.itemDescription_value.SetValue(compound.description)
-        self.itemFormula_value.SetValue(compound.rawFormula)
+        self.itemFormula_value.SetValue(compound.expression)
     # ----
     
     
@@ -484,7 +484,7 @@ class dlgCompoundsEditor(wx.Dialog):
             mass = compound.mass()
             self.itemsMap.append((
                 name,
-                compound.rawFormula,
+                compound.expression,
                 mass[0],
                 mass[1],
                 compound.description,
