@@ -105,10 +105,10 @@ class dlgEnzymesEditor(wx.Dialog):
         self.itemExpression_value = wx.TextCtrl(self, -1, "", size=(200, -1))
         
         itemCTerm_label = wx.StaticText(self, -1, "C-term formula:")
-        self.itemCTerm_value = wx.TextCtrl(self, -1, "", size=(200, -1))
+        self.itemCTerm_value = mwx.formulaCtrl(self, -1, "", size=(200, -1))
         
         itemNTerm_label = wx.StaticText(self, -1, "N-term formula:")
-        self.itemNTerm_value = wx.TextCtrl(self, -1, "", size=(200, -1))
+        self.itemNTerm_value = mwx.formulaCtrl(self, -1, "", size=(200, -1))
         
         self.itemModsBefore_check = wx.CheckBox(self, -1, "Allow modification before cut")
         
@@ -307,14 +307,14 @@ class dlgEnzymesEditor(wx.Dialog):
         # make enzyme
         try:
             expr = re.compile(expression)
-            enzyme = mspy.enzyme( \
-                    name=name, \
-                    expression=expression, \
-                    cTermFormula=cTermFormula, \
-                    nTermFormula=nTermFormula, \
-                    modsBefore=modsBefore, \
-                    modsAfter=modsAfter \
-                )
+            enzyme = mspy.enzyme(
+                name = name,
+                expression = expression,
+                cTermFormula = cTermFormula,
+                nTermFormula = nTermFormula,
+                modsBefore = modsBefore,
+                modsAfter = modsAfter
+            )
         except:
             wx.Bell()
             return False
