@@ -73,7 +73,7 @@ class dlgModificationsEditor(wx.Dialog):
         """Make list for items."""
         
         # init list
-        self.itemsList = mwx.sortListCtrl(self, -1, size=(751, 250), style=mwx.LISTCTRL_STYLE_MULTI)
+        self.itemsList = mwx.sortListCtrl(self, -1, size=(771, 250), style=mwx.LISTCTRL_STYLE_MULTI)
         self.itemsList.SetFont(wx.SMALL_FONT)
         self.itemsList.setAltColour(mwx.LISTCTRL_ALTCOLOUR)
         
@@ -91,7 +91,7 @@ class dlgModificationsEditor(wx.Dialog):
         self.itemsList.InsertColumn(7, "description", wx.LIST_FORMAT_LEFT)
         
         # set column widths
-        for col, width in enumerate((110,100,60,80,80,100,50,150)):
+        for col, width in enumerate((110,100,60,90,90,100,50,150)):
             self.itemsList.SetColumnWidth(col, width)
     # ----
     
@@ -116,11 +116,11 @@ class dlgModificationsEditor(wx.Dialog):
         self.itemTermSpecifity_combo.SetValue('None')
         
         itemGainFormula_label = wx.StaticText(self, -1, "Gain formula:")
-        self.itemGainFormula_value = wx.TextCtrl(self, -1, "", size=(150, -1))
+        self.itemGainFormula_value = mwx.formulaCtrl(self, -1, "", size=(150, -1))
         self.itemGainFormula_value.Bind(wx.EVT_TEXT, self.onFormulaEdited)
         
         itemLossFormula_label = wx.StaticText(self, -1, "Loss formula:")
-        self.itemLossFormula_value = wx.TextCtrl(self, -1, "", size=(150, -1))
+        self.itemLossFormula_value = mwx.formulaCtrl(self, -1, "", size=(150, -1))
         self.itemLossFormula_value.Bind(wx.EVT_TEXT, self.onFormulaEdited)
         
         itemMoMass_label = wx.StaticText(self, -1, "Mo. mass:")
@@ -382,13 +382,13 @@ class dlgModificationsEditor(wx.Dialog):
         
         # make compound
         try:
-            modification = mspy.modification( \
-                    name=name, \
-                    gainFormula=gainFormula, \
-                    lossFormula=lossFormula, \
-                    aminoSpecifity=aminoSpecifity, \
-                    termSpecifity=termSpecifity, \
-                    description=description \
+            modification = mspy.modification(
+                    name = name,
+                    gainFormula = gainFormula,
+                    lossFormula = lossFormula,
+                    aminoSpecifity = aminoSpecifity,
+                    termSpecifity = termSpecifity,
+                    description = description
                 )
         except:
             wx.Bell()
