@@ -67,7 +67,7 @@ class dlgNotation(wx.Dialog):
         self.label_value.Bind(wx.EVT_TEXT_ENTER, self.onOK)
         
         formula_label = wx.StaticText(self, -1, "Formula:", style=wx.ALIGN_RIGHT)
-        self.formula_value = wx.TextCtrl(self, -1, '', size=(300,-1), style=wx.TE_PROCESS_ENTER)
+        self.formula_value = mwx.formulaCtrl(self, -1, '', size=(300,-1), style=wx.TE_PROCESS_ENTER)
         self.formula_value.Bind(wx.EVT_TEXT, self.onFormula)
         self.formula_value.Bind(wx.EVT_TEXT_ENTER, self.onOK)
         
@@ -241,6 +241,9 @@ class dlgNotation(wx.Dialog):
     def onFormula(self, evt=None):
         """Check formula and calculate m/z."""
         
+        if evt != None:
+            evt.Skip()
+        
         # user-defined m/z
         if self.mzByUser_radio.GetValue():
             return
