@@ -54,9 +54,9 @@ class dlgPreferences(wx.Dialog):
         self.notebook = wx.Notebook(self, -1)
         
         # add pages
-        self.notebook.AddPage(self.makeUpdatesPage(), 'Software Updates')
         if wx.Platform == '__WXMSW__':
             self.notebook.AddPage(self.makeCompassPanel(), 'CompassXport')
+        self.notebook.AddPage(self.makeUpdatesPage(), 'Software Updates')
         
         # pack elements
         mainSizer = wx.BoxSizer(wx.VERTICAL)
@@ -149,7 +149,7 @@ class dlgPreferences(wx.Dialog):
     
     def onUpdateNow(self, evt):
         """Check for available updates now."""
-        self.parent.onUpdate()
+        self.parent.onHelpUpdate()
     # ----
     
     
