@@ -337,7 +337,7 @@ class dlgReferencesEditor(wx.Dialog):
             return
         
         # delete selected group
-        title = 'Do you realy want to delete selected group?'
+        title = 'Do you really want to delete selected group?'
         message = 'All references within the group will be lost.'
         buttons = [(wx.ID_CANCEL, "Cancel", 80, False, 15), (wx.ID_OK, "Delete", 80, True, 0)]
         dlg = mwx.dlgMessage(self, title, message, buttons)
@@ -388,7 +388,7 @@ class dlgReferencesEditor(wx.Dialog):
             return
         
         # delete?
-        title = 'Do you realy want to delete selected references?'
+        title = 'Do you really want to delete selected references?'
         message = 'Reference definitions will be lost.'
         buttons = [(wx.ID_CANCEL, "Cancel", 80, False, 15), (wx.ID_OK, "Delete", 80, True, 0)]
         dlg = mwx.dlgMessage(self, title, message, buttons)
