@@ -184,7 +184,7 @@ class document():
         """Make mSD XML."""
         
         buff = '<?xml version="1.0" encoding="utf-8" ?>\n'
-        buff += '<mSD version="2.1">\n\n'
+        buff += '<mSD version="2.2">\n\n'
         
         # format description
         buff += '  <description>\n'
@@ -223,80 +223,99 @@ class document():
         buff += '  </spectrum>\n\n'
         
         # format peaklist
-        buff += '  <peaklist>\n'
-        for peak in self.spectrum.peaklist:
-            attributes = 'mz="%.6f" intensity="%.6f" baseline="%.6f"' % (peak.mz, peak.ai, peak.base)
-            if peak.sn != None:
-                attributes += ' sn="%.3f"' % peak.sn
-            if peak.charge != None:
-                attributes += ' charge="%d"' % peak.charge
-            if peak.isotope != None:
-                attributes += ' isotope="%d"' % peak.isotope
-            if peak.fwhm != None:
-                attributes += ' fwhm="%.6f"' % peak.fwhm
-            if peak.group:
-                attributes += ' group="%s"' % self._escape(peak.group)
-            buff += '    <peak %s />\n' % attributes
-        buff += '  </peaklist>\n\n'
+        if len(self.spectrum.peaklist):
+            buff += '  <peaklist>\n'
+            for peak in self.spectrum.peaklist:
+                attributes = 'mz="%.6f" intensity="%.6f" baseline="%.6f"' % (peak.mz, peak.ai, peak.base)
+                if peak.sn != None:
+                    attributes += ' sn="%.3f"' % peak.sn
+                if peak.charge != None:
+                    attributes += ' charge="%d"' % peak.charge
+                if peak.isotope != None:
+                    attributes += ' isotope="%d"' % peak.isotope
+                if peak.fwhm != None:
+                    attributes += ' fwhm="%.6f"' % peak.fwhm
+                if peak.group:
+                    attributes += ' group="%s"' % self._escape(peak.group)
+                buff += '    <peak %s />\n' % attributes
+            buff += '  </peaklist>\n\n'
         
         # format annotations
-        buff += '  <annotations>\n'
-        for annot in self.annotations:
-            attributes = 'peakMZ="%.6f" peakIntensity="%.6f" peakBaseline="%.6f"' % (annot.mz, annot.ai, annot.base)
-            if annot.charge != None:
-                attributes += ' charge="%d"' % annot.charge
-            if annot.radical:
-                attributes += ' radical="1"'
-            if annot.theoretical != None:
-                attributes += ' calcMZ="%.6f"' % annot.theoretical
-            if annot.formula != None:
-                attributes += ' formula="%s"' % annot.formula
-            buff += '    <annotation %s>%s</annotation>\n' % (attributes, self._escape(annot.label))
-        buff += '  </annotations>\n\n'
+        if len(self.annotations):
+            buff += '  <annotations>\n'
+            for annot in self.annotations:
+                attributes = 'peakMZ="%.6f" peakIntensity="%.6f" peakBaseline="%.6f"' % (annot.mz, annot.ai, annot.base)
+                if annot.charge != None:
+                    attributes += ' charge="%d"' % annot.charge
+                if annot.radical:
+                    attributes += ' radical="1"'
+                if annot.theoretical != None:
+                    attributes += ' calcMZ="%.6f"' % annot.theoretical
+                if annot.formula != None:
+                    attributes += ' formula="%s"' % annot.formula
+                buff += '    <annotation %s>%s</annotation>\n' % (attributes, self._escape(annot.label))
+            buff += '  </annotations>\n\n'
         
         # format sequences
-        buff += '  <sequences>\n\n'
-        for index, sequence in enumerate(self.sequences):
-            attributes = 'index="%d"' % index
-            buff += '    <sequence %s>\n' % attributes
-            buff += '      <title>%s</title>\n' % self._escape(sequence.title)
-            buff += '      <accession>%s</accession>\n' % self._escape(sequence.accession)
-            buff += '      <seq>%s</seq>\n' % sequence.format('S')
-            
-            # format modifications
-            buff += '      <modifications>\n'
-            for mod in sequence.modifications:
-                gainFormula = mspy.modifications[mod[0]].gainFormula
-                lossFormula = mspy.modifications[mod[0]].lossFormula
-                modtype = 'fixed'
-                if mod[2] == 'v':
-                    modtype = 'variable'
-                buff += '        <modification name="%s" position="%s" type="%s" gainFormula="%s" lossFormula="%s" />\n' % (mod[0], mod[1], modtype, gainFormula, lossFormula)
-            buff += '      </modifications>\n'
-            
-            # format matches
-            buff += '      <matches>\n'
-            for match in sequence.matches:
-                attributes = 'peakMZ="%.6f" peakIntensity="%.6f" peakBaseline="%.6f"' % (match.mz, match.ai, match.base)
-                if match.charge != None:
-                    attributes += ' charge="%d"' % match.charge
-                if match.radical:
-                    attributes += ' radical="1"'
-                if match.theoretical != None:
-                    attributes += ' calcMZ="%.6f"' % match.theoretical
-                if match.formula != None:
-                    attributes += ' formula="%s"' % match.formula
-                if match.sequenceRange != None:
-                    attributes += ' sequenceRange="%d-%d"' % tuple(match.sequenceRange)
-                if match.fragmentSerie != None:
-                    attributes += ' fragmentSerie="%s"' % match.fragmentSerie
-                if match.fragmentIndex != None:
-                    attributes += ' fragmentIndex="%s"' % match.fragmentIndex
-                buff += '        <match %s>%s</match>\n' % (attributes, self._escape(match.label))
-            buff += '      </matches>\n'
-            
-            buff += '    </sequence>\n\n'
-        buff += '  </sequences>\n\n'
+        if len(self.sequences):
+            buff += '  <sequences>\n\n'
+            for index, sequence in enumerate(self.sequences):
+                buff += '    <sequence index="%s">\n' % index
+                buff += '      <title>%s</title>\n' % self._escape(sequence.title)
+                buff += '      <accession>%s</accession>\n' % self._escape(sequence.accession)
+                
+                attributes = 'type="%s"' % sequence.chainType
+                if sequence.cyclic:
+                    attributes += ' cyclic="1"'
+                buff += '      <seq %s>%s</seq>\n' % (attributes, sequence.format('S'))
+                
+                # save monomers for custom sequences
+                if sequence.chainType != 'aminoacids':
+                    buff += '      <monomers>\n'
+                    savedMonomers = []
+                    for abbr in sequence.chain:
+                        if not abbr in savedMonomers:
+                            savedMonomers.append(abbr)
+                            formula = mspy.monomers[abbr].formula
+                            buff += '        <monomer abbr="%s" formula="%s" />\n' % (abbr, formula)
+                    buff += '      </monomers>\n'
+                
+                # format modifications
+                if len(sequence.modifications):
+                    buff += '      <modifications>\n'
+                    for mod in sequence.modifications:
+                        gainFormula = mspy.modifications[mod[0]].gainFormula
+                        lossFormula = mspy.modifications[mod[0]].lossFormula
+                        modtype = 'fixed'
+                        if mod[2] == 'v':
+                            modtype = 'variable'
+                        buff += '        <modification name="%s" position="%s" type="%s" gainFormula="%s" lossFormula="%s" />\n' % (mod[0], mod[1], modtype, gainFormula, lossFormula)
+                    buff += '      </modifications>\n'
+                
+                # format matches
+                if len(sequence.matches):
+                    buff += '      <matches>\n'
+                    for match in sequence.matches:
+                        attributes = 'peakMZ="%.6f" peakIntensity="%.6f" peakBaseline="%.6f"' % (match.mz, match.ai, match.base)
+                        if match.charge != None:
+                            attributes += ' charge="%d"' % match.charge
+                        if match.radical:
+                            attributes += ' radical="1"'
+                        if match.theoretical != None:
+                            attributes += ' calcMZ="%.6f"' % match.theoretical
+                        if match.formula != None:
+                            attributes += ' formula="%s"' % match.formula
+                        if match.sequenceRange != None:
+                            attributes += ' sequenceRange="%d-%d"' % tuple(match.sequenceRange)
+                        if match.fragmentSerie != None:
+                            attributes += ' fragmentSerie="%s"' % match.fragmentSerie
+                        if match.fragmentIndex != None:
+                            attributes += ' fragmentIndex="%s"' % match.fragmentIndex
+                        buff += '        <match %s>%s</match>\n' % (attributes, self._escape(match.label))
+                    buff += '      </matches>\n'
+                
+                buff += '    </sequence>\n\n'
+            buff += '  </sequences>\n\n'
         
         buff += '</mSD>\n'
         
@@ -375,8 +394,9 @@ class document():
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 2);" title="Sort by">&delta;&nbsp;(Da)</a></th>\n'
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 3);" title="Sort by">&delta;&nbsp;(ppm)</a></th>\n'
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 4);" title="Sort by">Rel.&nbsp;Int.&nbsp;(%)</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">Annotation</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">Formula</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">z</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">Annotation</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 7);" title="Sort by">Formula</a></th>\n'
             buff += '      </tr>\n'
             buff += '    </thead>\n'
             buff += '    <tbody id="%s">\n' % tableID
@@ -384,6 +404,7 @@ class document():
                 mz = mzFormat % annot.mz
                 relIntensity = ''
                 theoretical = ''
+                charge = ''
                 deltaDa = ''
                 deltaPpm = ''
                 formula = ''
@@ -397,8 +418,12 @@ class document():
                     deltaPpm = ppmFormat % annot.delta('ppm')
                 if annot.formula:
                     formula = annot.formula
+                if annot.charge:
+                    charge = annot.charge
+                if annot.radical:
+                    charge = str(annot.charge) + ' &bull;'
                 
-                buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, relIntensity, label, formula)
+                buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="center nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, relIntensity, charge, label, formula)
             buff += '    </tbody>\n'
             buff += '  </table>\n'
         
@@ -411,8 +436,13 @@ class document():
                 avMass = mzFormat % mass[1]
                 chain = self._formatSequence(sequence)
                 coverage = self._getSequenceCoverage(sequence)
+                matchedInt = self._getMatchedIntensity(self.spectrum.peaklist, sequence.matches)
                 tableID = 'tableSequenceMatches%d' % x
                 
+                cyclic = ''
+                if sequence.cyclic:
+                    cyclic = ' (Cyclic)'
+                
                 if accession:
                     buff += '  <h2>Sequence - <span>%s</span> - [%s]</h2>\n' % (sequence.title, accession)
                 else:
@@ -420,11 +450,11 @@ class document():
                 
                 buff += '  <table id="tableSequenceInfo">\n'
                 buff += '    <thead>\n'
-                buff += '      <tr><th>Accession</th><th>Aminoacids</th><th>Mo. Mass</th><th>Av. Mass</th><th>Coverage</th></tr>\n'
+                buff += '      <tr><th>Accession</th><th>Length</th><th>Mo. Mass</th><th>Av. Mass</th><th>Coverage</th><th>Matched Int.</th></tr>\n'
                 buff += '    </thead>\n'
                 buff += '    <tbody>\n'
-                buff += '      <tr><td class="right">%s</td><td class="right">%s</td><td class="right">%s</td><td class="right">%s</td><td class="right">%s</td></tr>\n' % (accession, len(sequence), moMass, avMass, coverage)
-                buff += '      <tr><td colspan="5" class="sequence">%s</td></tr>\n' % chain
+                buff += '      <tr><td class="right">%s</td><td class="right">%s%s</td><td class="right">%s</td><td class="right">%s</td><td class="right">%s</td><td class="right">%s</td></tr>\n' % (accession, len(sequence), cyclic, moMass, avMass, coverage, matchedInt)
+                buff += '      <tr><td colspan="6" class="sequence">%s</td></tr>\n' % chain
                 buff += '    </tbody>\n'
                 buff += '  </table>\n'
                 
@@ -448,8 +478,9 @@ class document():
                     buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 2);" title="Sort by">&delta;&nbsp;(Da)</a></th>\n'
                     buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 3);" title="Sort by">&delta;&nbsp;(ppm)</a></th>\n'
                     buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 4);" title="Sort by">Rel.&nbsp;Int.&nbsp;(%)</a></th>\n'
-                    buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">Annotation</a></th>\n'
-                    buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">Formula</a></th>\n'
+                    buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">z</a></th>\n'
+                    buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">Annotation</a></th>\n'
+                    buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 7);" title="Sort by">Formula</a></th>\n'
                     buff += '      </tr>\n'
                     buff += '    </thead>\n'
                     buff += '    <tbody id="%s">\n' % tableID
@@ -457,6 +488,7 @@ class document():
                         mz = mzFormat % m.mz
                         relIntensity = ''
                         theoretical = ''
+                        charge = ''
                         deltaDa = ''
                         deltaPpm = ''
                         formula = ''
@@ -469,8 +501,12 @@ class document():
                             deltaPpm = ppmFormat % m.delta('ppm')
                         if m.formula:
                             formula = m.formula
+                        if m.charge:
+                            charge = m.charge
+                        if m.radical:
+                            charge = str(m.charge) + ' &bull;'
                         
-                        buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, relIntensity, m.label, formula)
+                        buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="center nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, relIntensity, charge, m.label, formula)
                     buff += '    </tbody>\n'
                     buff += '  </table>\n'
         
@@ -536,19 +572,22 @@ class document():
         
         # format sequence
         buff = ''
-        for x, amino in enumerate(sequence):
+        for x, monomer in enumerate(sequence):
             attributes = ''
             
             if sequence.ismodified(x, True):
                 attributes += 'modified '
             if coverage[x]:
                 attributes += 'matched '
-            if attributes:
-                buff += '<span class="%s">%s</span>' % (attributes, amino)
-            else:
-                buff += amino
             
-            if not (x+1) % 10:
+            if attributes:
+                buff += '<span class="%s">%s</span>' % (attributes, monomer)
+            else:
+                buff += monomer
+            
+            if sequence.chainType != 'aminoacids' and (x+1) != len(sequence):
+                buff += ' | '
+            elif not (x+1) % 10:
                 buff += ' '
         
         return buff
@@ -611,6 +650,34 @@ class document():
     # ----
     
     
+    def _getMatchedIntensity(self, peaklist, matches):
+        """Get total matched intensity."""
+        
+        # get total intensity
+        totalInt = 0
+        buff = {}
+        for peak in peaklist:
+            totalInt += peak.intensity
+            buff[round(peak.mz, 6)] = peak.intensity
+        
+        # get matched intensity
+        matchedInt = 0
+        for item in matches:
+            mz = round(item.mz, 6)
+            if mz in buff:
+                matchedInt += buff[mz]
+                del buff[mz]
+        
+        # get percentage
+        matched = '0.0'
+        if totalInt:
+            matched = '%.1f' % (100*matchedInt/totalInt)
+        matched += ' %'
+        
+        return matched
+    # ----
+    
+    
     def _replaceLabelIDs(self, section, label):
         """Replace IDs with links in annotations."""
         
@@ -709,6 +776,7 @@ class parseMSD():
     def __init__(self, path):
         
         self.path = path
+        self.errors = []
         self._version = None
         self._parsedData = None
         
@@ -722,6 +790,8 @@ class parseMSD():
     def getDocument(self):
         """Get document."""
         
+        self.errors = []
+        
         # parse data
         if not self._parsedData:
             try:
@@ -752,6 +822,8 @@ class parseMSD():
     def getSequences(self):
         """Get list of available sequences."""
         
+        self.errors = []
+        
         # parse data
         if not self._parsedData:
             try:
@@ -955,6 +1027,7 @@ class parseMSD():
                         group = peakTag.getAttribute('group')
                     
                 except ValueError:
+                    self.errors.append('Incorrect peak data.')
                     continue
                 
                 # make peak
@@ -1005,6 +1078,7 @@ class parseMSD():
                     annot = annotation(label=label, mz=mz, ai=ai, base=base, charge=charge, radical=radical, theoretical=theoretical, formula=formula)
                     
                 except ValueError:
+                    self.errors.append('Incorrect annotation data.')
                     continue
                 
                 # append annotation
@@ -1044,17 +1118,34 @@ class parseMSD():
         if accessionTags:
             accession = self._getNodeText(accessionTags[0])
         
-        # get sequence
+        # get chain
         chain = ''
+        chainType = 'aminoacids'
+        cyclic = False
         seqTags = sequenceTag.getElementsByTagName('seq')
         if seqTags:
             chain = self._getNodeText(seqTags[0])
+            
+            if seqTags[0].hasAttribute('type'):
+                chainType = str(seqTags[0].getAttribute('type'))
+            if seqTags[0].hasAttribute('cyclic'):
+                try: cyclic = bool(int(seqTags[0].getAttribute('cyclic')))
+                except ValueError: pass
+        
+        # get monomers
+        monomerTags = sequenceTag.getElementsByTagName('monomer')
+        for monomerTag in monomerTags:
+            abbr = monomerTag.getAttribute('abbr')
+            formula = monomerTag.getAttribute('formula')
+            if not abbr in mspy.monomers:
+                self._addMonomer(abbr, formula)
         
         # make sequence
         try:
-            sequence = mspy.sequence(chain, title=title, accession=accession)
+            sequence = mspy.sequence(chain, title=title, accession=accession, chainType=chainType, cyclic=cyclic)
             sequence.matches = []
         except:
+            self.errors.append('Unknown monomers in sequence data.')
             return False
         
         # get modifications
@@ -1079,6 +1170,16 @@ class parseMSD():
                 if self._addModification(name, gainFormula, lossFormula):
                     sequence.modify(name, position, modtype)
         
+        # get matches
+        sequence.matches[:] = self.handleSequenceMatches(sequenceTag)
+        
+        return sequence
+    # ----
+    
+    
+    def handleSequenceMatches(self, sequenceTag):
+        """Get sequence amtches."""
+        
         # get matches
         matches = []
         matchTags = sequenceTag.getElementsByTagName('match')
@@ -1121,12 +1222,13 @@ class parseMSD():
                 m.fragmentSerie = fragmentSerie
                 m.fragmentIndex = fragmentIndex
                 
-                sequence.matches.append(m)
+                matches.append(m)
             
             except ValueError:
+                self.errors.append('Incorrect sequence match data.')
                 continue
         
-        return sequence
+        return matches
     # ----
     
     
@@ -1152,6 +1254,7 @@ class parseMSD():
                     ai = float(peakTag.getAttribute('intens'))
                     annot = peakTag.getAttribute('annots')
                 except ValueError:
+                    self.errors.append('Incorrect peak data.')
                     continue
                 
                 # make peak
@@ -1202,6 +1305,7 @@ class parseMSD():
             sequence = mspy.sequence(chain, title=title)
             sequence.matches = []
         except:
+            self.errors.append('Unknown monomers in sequence data.')
             return False
         
         # get modifications
@@ -1251,6 +1355,7 @@ class parseMSD():
             return data
         
         except:
+            self.errors.append('Incorrect spectrum data.')
             return False
     # ----
     
@@ -1289,28 +1394,39 @@ class parseMSD():
     # ----
     
     
-    def _addModification(self, name, gainFormula, lossFormula):
-        """Add modification to the library."""
+    def _addMonomer(self, abbr, formula, losses=[], name='', category=''):
+        """Add monomer to library."""
         
-        # check name
-        if not name or name in mspy.modifications:
+        # check data
+        if not abbr or not formula or not re.match('^[A-Za-z0-9\-_]*$', abbr):
             return False
         
-        # check gain and loss
-        if not gainFormula and not lossFormula:
-            return False
+        # add new monomer
         try:
-            formula = mspy.compound(gainFormula)
-            formula = mspy.compound(lossFormula)
+            monomer = mspy.monomer(abbr=abbr, formula=formula, losses=losses, name=name, category=category)
+            mspy.monomers[abbr] = monomer
+            mspy.saveMonomers(os.path.join(config.confdir,'monomers.xml'))
+            return True
         except:
             return False
+    # ----
+    
+    
+    def _addModification(self, name, gainFormula, lossFormula, aminoSpecifity=''):
+        """Add modification to library."""
         
-        # make modification
-        modification = mspy.modification(name=name, gainFormula=gainFormula, lossFormula=lossFormula, aminoSpecifity='ACDEFGHIKLMNPQRSTVWY')
-        mspy.modifications[name] = modification
-        mspy.saveModifications()
+        # check data
+        if not name or not (gainFormula or lossFormula):
+            return False
         
-        return True
+        # add new modification
+        try:
+            modification = mspy.modification(name=name, gainFormula=gainFormula, lossFormula=lossFormula, aminoSpecifity=aminoSpecifity)
+            mspy.modifications[name] = modification
+            mspy.saveModifications(os.path.join(config.confdir,'modifications.xml'))
+            return True
+        except:
+            return False
     # ----
     
     
@@ -1343,8 +1459,10 @@ REPORT_HEADER = """<?xml version="1.0" encoding="utf-8"?>
     #tableMainInfo td{text-align: left;}
     #spectrum{text-align: center;}
     #footer{font-size: .8em; font-style: italic; text-align: center; color: #aaa; margin: 2em 0 1em 0; padding-top: 0.5em; border-top: 1px solid #000;}
-    .nowrap{white-space:nowrap;}
+    .left{text-align: left;}
     .right{text-align: right;}
+    .center{text-align: center;}
+    .nowrap{white-space:nowrap;}
     .sequence{font-size: 1.1em; font-family: monospace;}
     .modified{color: #f00; font-weight: bold;}
     .matched{text-decoration: underline;}
