@@ -115,6 +115,7 @@ def loadImages():
     lib['bgrToolbar'] = images_lib.getBgrToolbarBitmap()
     lib['bgrToolbarNoBorder'] = images_lib.getBgrToolbarNoBorderBitmap()
     lib['bgrControlbar'] = images_lib.getBgrControlbarBitmap()
+    lib['bgrControlbarDouble'] = images_lib.getBgrControlbarDoubleBitmap()
     lib['bgrBottombar'] = images_lib.getBgrBottombarBitmap()
     lib['bgrPeakEditor'] = images_lib.getBgrPeakEditorBitmap()
     
@@ -132,27 +133,28 @@ def loadImages():
     # tools
     if wx.Platform == '__WXMAC__':
         tools = images_lib.getToolsBitmap()
-        lib['toolsProcessing'] = tools.GetSubBitmap(wx.Rect(0, 0, 30, 22))
-        lib['toolsCalibration'] = tools.GetSubBitmap(wx.Rect(30, 0, 30, 22))
-        lib['toolsSequence'] = tools.GetSubBitmap(wx.Rect(60, 0, 30, 22))
-        lib['toolsMassCalculator'] = tools.GetSubBitmap(wx.Rect(90, 0, 30, 22))
-        lib['toolsCompoundsSearch'] = tools.GetSubBitmap(wx.Rect(120, 0, 30, 22))
-        lib['toolsPeakDifferences'] = tools.GetSubBitmap(wx.Rect(150, 0, 30, 22))
-        lib['toolsComparePeaklists'] = tools.GetSubBitmap(wx.Rect(180, 0, 30, 22))
-        lib['toolsMascot'] = tools.GetSubBitmap(wx.Rect(210, 0, 30, 22))
-        lib['toolsProfound'] = tools.GetSubBitmap(wx.Rect(240, 0, 30, 22))
-        lib['toolsDocumentInfo'] = tools.GetSubBitmap(wx.Rect(270, 0, 30, 22))
-        lib['toolsDocumentReport'] = tools.GetSubBitmap(wx.Rect(300, 0, 30, 22))
-        lib['toolsDocumentExport'] = tools.GetSubBitmap(wx.Rect(330, 0, 30, 22))
+        lib['toolsProcessing'] = tools.GetSubBitmap(wx.Rect(0, 0, 30, 23))
+        lib['toolsCalibration'] = tools.GetSubBitmap(wx.Rect(30, 0, 30, 23))
+        lib['toolsSequence'] = tools.GetSubBitmap(wx.Rect(60, 0, 30, 23))
+        lib['toolsMassCalculator'] = tools.GetSubBitmap(wx.Rect(90, 0, 30, 23))
+        lib['toolsCompoundsSearch'] = tools.GetSubBitmap(wx.Rect(120, 0, 30, 23))
+        lib['toolsPeakDifferences'] = tools.GetSubBitmap(wx.Rect(150, 0, 30, 23))
+        lib['toolsComparePeaklists'] = tools.GetSubBitmap(wx.Rect(180, 0, 30, 23))
+        lib['toolsMascot'] = tools.GetSubBitmap(wx.Rect(210, 0, 30, 23))
+        lib['toolsProfound'] = tools.GetSubBitmap(wx.Rect(240, 0, 30, 23))
+        lib['toolsDocumentInfo'] = tools.GetSubBitmap(wx.Rect(270, 0, 30, 23))
+        lib['toolsDocumentReport'] = tools.GetSubBitmap(wx.Rect(300, 0, 30, 23))
+        lib['toolsDocumentExport'] = tools.GetSubBitmap(wx.Rect(330, 0, 30, 23))
         lib['toolsPresets'] = tools.GetSubBitmap(wx.Rect(360, 0, 30, 22))
-        lib['toolsMassFilter'] = tools.GetSubBitmap(wx.Rect(390, 0, 30, 22))
-        lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(420, 0, 30, 22))
+        lib['toolsMassFilter'] = tools.GetSubBitmap(wx.Rect(390, 0, 30, 23))
+        lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(420, 0, 30, 23))
+        lib['toolsEnvelopeFit'] = tools.GetSubBitmap(wx.Rect(450, 0, 30, 23))
+        lib['toolsLibrary'] = tools.GetSubBitmap(wx.Rect(480, 0, 30, 22))
     else:
         tools = images_lib.getToolsBitmap()
         lib['toolsOpen'] = tools.GetSubBitmap(wx.Rect(0, 0, 22, 22))
         lib['toolsSave'] = tools.GetSubBitmap(wx.Rect(22, 0, 22, 22))
         lib['toolsPrint'] = tools.GetSubBitmap(wx.Rect(44, 0, 22, 22))
-        
         lib['toolsProcessing'] = tools.GetSubBitmap(wx.Rect(66, 0, 22, 22))
         lib['toolsCalibration'] = tools.GetSubBitmap(wx.Rect(88, 0, 22, 22))
         lib['toolsSequence'] = tools.GetSubBitmap(wx.Rect(110, 0, 22, 22))
@@ -168,6 +170,8 @@ def loadImages():
         lib['toolsPresets'] = tools.GetSubBitmap(wx.Rect(330, 0, 22, 22))
         lib['toolsMassFilter'] = tools.GetSubBitmap(wx.Rect(352, 0, 22, 22))
         lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(374, 0, 22, 22))
+        lib['toolsEnvelopeFit'] = tools.GetSubBitmap(wx.Rect(396, 0, 22, 22))
+        lib['toolsLibrary'] = tools.GetSubBitmap(wx.Rect(418, 0, 22, 22))
     
     # bottombars
     bottombarsOn = images_lib.getBottombarsOnBitmap()
@@ -182,25 +186,24 @@ def loadImages():
     lib['peaklistEditorOn'] = bottombarsOn.GetSubBitmap(wx.Rect(87, 22, 29, 22))
     lib['peaklistEditorOff'] = bottombarsOff.GetSubBitmap(wx.Rect(87, 22, 29, 22))
     
-    lib['spectrumParams'] = bottombarsOff.GetSubBitmap(wx.Rect(0, 44, 29, 22))
-    lib['spectrumLabelsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(29, 44, 29, 22))
-    lib['spectrumLabelsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(29, 44, 29, 22))
-    lib['spectrumTicksOn'] = bottombarsOn.GetSubBitmap(wx.Rect(58, 44, 29, 22))
-    lib['spectrumTicksOff'] = bottombarsOff.GetSubBitmap(wx.Rect(58, 44, 29, 22))
-    lib['spectrumNotationsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(87, 44, 29, 22))
-    lib['spectrumNotationsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(87, 44, 29, 22))
-    lib['spectrumLabelAngleOn'] = bottombarsOn.GetSubBitmap(wx.Rect(116, 44, 29, 22))
-    lib['spectrumLabelAngleOff'] = bottombarsOff.GetSubBitmap(wx.Rect(116, 44, 29, 22))
-    lib['spectrumPosBarsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(145, 44, 29, 22))
-    lib['spectrumPosBarsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(145, 44, 29, 22))
-    lib['spectrumGelOn'] = bottombarsOn.GetSubBitmap(wx.Rect(174, 44, 29, 22))
-    lib['spectrumGelOff'] = bottombarsOff.GetSubBitmap(wx.Rect(174, 44, 29, 22))
-    lib['spectrumTrackerOn'] = bottombarsOn.GetSubBitmap(wx.Rect(203, 44, 29, 22))
-    lib['spectrumTrackerOff'] = bottombarsOff.GetSubBitmap(wx.Rect(203, 44, 29, 22))
-    lib['spectrumAutoscaleOn'] = bottombarsOn.GetSubBitmap(wx.Rect(232, 44, 29, 22))
-    lib['spectrumAutoscaleOff'] = bottombarsOff.GetSubBitmap(wx.Rect(232, 44, 29, 22))
-    lib['spectrumNormalizeOn'] = bottombarsOn.GetSubBitmap(wx.Rect(261, 44, 29, 22))
-    lib['spectrumNormalizeOff'] = bottombarsOff.GetSubBitmap(wx.Rect(261, 44, 29, 22))
+    lib['spectrumLabelsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(0, 44, 29, 22))
+    lib['spectrumLabelsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(0, 44, 29, 22))
+    lib['spectrumTicksOn'] = bottombarsOn.GetSubBitmap(wx.Rect(29, 44, 29, 22))
+    lib['spectrumTicksOff'] = bottombarsOff.GetSubBitmap(wx.Rect(29, 44, 29, 22))
+    lib['spectrumNotationsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(58, 44, 29, 22))
+    lib['spectrumNotationsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(58, 44, 29, 22))
+    lib['spectrumLabelAngleOn'] = bottombarsOn.GetSubBitmap(wx.Rect(87, 44, 29, 22))
+    lib['spectrumLabelAngleOff'] = bottombarsOff.GetSubBitmap(wx.Rect(87, 44, 29, 22))
+    lib['spectrumPosBarsOn'] = bottombarsOn.GetSubBitmap(wx.Rect(116, 44, 29, 22))
+    lib['spectrumPosBarsOff'] = bottombarsOff.GetSubBitmap(wx.Rect(116, 44, 29, 22))
+    lib['spectrumGelOn'] = bottombarsOn.GetSubBitmap(wx.Rect(145, 44, 29, 22))
+    lib['spectrumGelOff'] = bottombarsOff.GetSubBitmap(wx.Rect(145, 44, 29, 22))
+    lib['spectrumTrackerOn'] = bottombarsOn.GetSubBitmap(wx.Rect(174, 44, 29, 22))
+    lib['spectrumTrackerOff'] = bottombarsOff.GetSubBitmap(wx.Rect(174, 44, 29, 22))
+    lib['spectrumAutoscaleOn'] = bottombarsOn.GetSubBitmap(wx.Rect(203, 44, 29, 22))
+    lib['spectrumAutoscaleOff'] = bottombarsOff.GetSubBitmap(wx.Rect(203, 44, 29, 22))
+    lib['spectrumNormalizeOn'] = bottombarsOn.GetSubBitmap(wx.Rect(232, 44, 29, 22))
+    lib['spectrumNormalizeOff'] = bottombarsOff.GetSubBitmap(wx.Rect(232, 44, 29, 22))
     
     lib['spectrumLabelPeakOn'] = bottombarsOn.GetSubBitmap(wx.Rect(0, 66, 29, 22))
     lib['spectrumLabelPeakOff'] = bottombarsOff.GetSubBitmap(wx.Rect(0, 66, 29, 22))
@@ -661,6 +664,7 @@ def convertImages():
             "-a -u -n BgrToolbar images/"+platform+"/bgr_toolbar.png images_lib_"+platform+".py",
             "-a -u -n BgrToolbarNoBorder images/"+platform+"/bgr_toolbar_noborder.png images_lib_"+platform+".py",
             "-a -u -n BgrControlbar images/"+platform+"/bgr_controlbar.png images_lib_"+platform+".py",
+            "-a -u -n BgrControlbarDouble images/"+platform+"/bgr_controlbar_double.png images_lib_"+platform+".py",
             "-a -u -n BgrBottombar images/"+platform+"/bgr_bottombar.png images_lib_"+platform+".py",
             "-a -u -n BgrPeakEditor images/"+platform+"/bgr_peakeditor.png images_lib_"+platform+".py",
             
