@@ -16,7 +16,9 @@
 # -------------------------------------------------------------------------
 
 # load libs
+import sys
 import os.path
+import shutil
 import xml.dom.minidom
 import copy
 
@@ -25,11 +27,20 @@ import config
 import mspy
 
 
+# ENSURE DEFAULT LIBS ARE AVAILABLE AFTER MAC INSTALLATION
+# --------------------------------------------------------
+if sys.platform == 'darwin':
+    for item in ('monomers.xml', 'modifications.xml', 'enzymes.xml', 'presets.xml', 'references.xml', 'compounds.xml', 'mascot.xml'):
+        if not os.path.exists(os.path.join(config.confdir, item)):
+            try: shutil.copyfile(os.path.join('configs', item), os.path.join(config.confdir, item))
+            except: pass
+
+
 # LOAD USER'S LIBS INTO MSPY
 # --------------------------
 
-try: mspy.loadAminoacids(os.path.join(config.confdir,'aminoacids.xml'), clear=False)
-except: mspy.saveAminoacids(os.path.join(config.confdir,'aminoacids.xml'))
+try: mspy.loadMonomers(os.path.join(config.confdir,'monomers.xml'), clear=False)
+except: mspy.saveMonomers(os.path.join(config.confdir,'monomers.xml'))
 
 try: mspy.loadModifications(os.path.join(config.confdir,'modifications.xml'), clear=False)
 except: mspy.saveModifications(os.path.join(config.confdir,'modifications.xml'))
@@ -76,7 +87,7 @@ presets = {
                 'removeIsotopes': 1,
                 'removeUnknown': 1,
                 'setAsMonoisotopic': 1,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -118,7 +129,7 @@ presets = {
                 'removeIsotopes': 1,
                 'removeUnknown': 1,
                 'setAsMonoisotopic': 1,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -160,7 +171,7 @@ presets = {
                 'removeIsotopes': 0,
                 'removeUnknown': 0,
                 'setAsMonoisotopic': 0,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -176,7 +187,7 @@ presets = {
                 'highMass': 4000,
             },
             'baseline':{
-                'precision': 100,
+                'precision': 20,
                 'offset': 0.25,
             },
             'smoothing':{
@@ -202,7 +213,7 @@ presets = {
                 'removeIsotopes': 1,
                 'removeUnknown': 0,
                 'setAsMonoisotopic': 1,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -244,7 +255,7 @@ presets = {
                 'removeIsotopes': 1,
                 'removeUnknown': 1,
                 'setAsMonoisotopic': 1,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -286,7 +297,7 @@ presets = {
                 'removeIsotopes': 1,
                 'removeUnknown': 1,
                 'setAsMonoisotopic': 1,
-                'labelEnvelope': 'monoisotopic',
+                'labelEnvelope': '1st',
                 'envelopeIntensity': 'maximum',
             },
             'deconvolution':{
@@ -299,15 +310,16 @@ presets = {
     },
     'modifications':{
         '-None-':[],
-        'Carbamidomethyl (C) Oxidation (MW)':[
+        'Carbamidomethyl (C)':[
             ['Carbamidomethyl', 'C', 'f'],
-            ['Oxidation', 'M', 'v'],
-            ['Oxidation', 'W', 'v'],
         ],
         'Oxidation (MW)':[
             ['Oxidation', 'M', 'v'],
             ['Oxidation', 'W', 'v'],
         ],
+        'N-Formyl Met':[
+            ['FormylMet', 0, 'v']
+        ],
     },
     'fragments':{
         '-None-':[],
@@ -321,71 +333,7 @@ presets = {
 }
 
 references = {
-    'PepMix Bruker - MALDI Pos Mo':[
-        ('Bradykinin (1-7) [M+H]+', 757.399150),
-        ('Angiotensin II [M+H]+', 1046.541792),
-        ('Angiotensin I [M+H]+', 1296.684768),
-        ('Substance P [M+H]+', 1347.735423),
-        ('Bombesin [M+H]+', 1619.822341),
-        ('ACTH clip (1-17) [M+H]+', 2093.086160),
-        ('ACTH clip (18-39) [M+H]+', 2465.198332),
-        ('Somatostatin 28 [M+H]+', 3147.470975),
-    ],
-    'PepMix Bruker - MALDI Neg Mo':[
-        ('Angiotensin II [M-H]-', 1044.527247),
-        ('Angiotensin I [M-H]-', 1294.670247),
-        ('Substance P [M-H]-', 1345.720847),
-        ('Bombesin [M-H]-', 1617.807747),
-        ('ACTH clip (1-17) [M-H]-', 2091.071647),
-        ('ACTH clip (18-39) [M-H]-', 2463.183747),
-        ('Somatostatin 28 [M-H]-', 3145.456447),
-    ],
-    'PepMix Bruker PAC - MALDI Pos Mo':[
-        ('Bradykinin (1-7) [M+H]+', 757.399160),
-        ('Angiotensin III [M+H]+', 931.514849),
-        ('Angiotensin II [M+H]+', 1046.541792),
-        ('Angiotensin I [M+H]+', 1296.684768),
-        ('Substance P [M+H]+', 1347.735423),
-        ('Bombesin [M+H]+', 1619.822341),
-        ('Neurotensin [M+H]+', 1672.917000),
-        ('Renin Substrate [M+H]+', 1758.932610),
-        ('ACTH clip (1-17) [M+H]+', 2093.086160),
-        ('ACTH clip (18-39) [M+H]+', 2465.198332),
-        ('ACTH clip (1-24) [M+H]+', 2932.587870),
-        ('Somatostatin 28 [M+H]+', 3147.470975),
-        ('ACTH clip (7-38) [M+H]+', 3657.928900),
-    ],
-    'ProtMix I Bruker - MALDI Pos Av':[
-        ('Insulin [M+H]+', 5735),
-        ('Cytochrome C [M+2H]2+', 6181),
-        ('Myoglobin [M+2H]2+', 8477),
-        ('Ubiquitin I [M+H]+', 8566),
-        ('Cytochrom C [M+H]+', 12361),
-        ('Myoglobin [M+H]+', 16953),
-    ],
-    'ProtMix I Bruker - MALDI Neg Av':[
-        ('Insulin [M-H]-', 5733),
-        ('Cytochrome C [M-2H]2-', 6179),
-        ('Myoglobin [M-2H]2-', 8475),
-        ('Ubiquitin I [M-H]-', 8564),
-        ('Cytochrom C [M-H]-', 12359),
-        ('Myoglobin [M-H]-', 16951),
-    ],
-    'ProtMix II Bruker - MALDI Pos Av':[
-        ('Trypsinogen [M+H]+', 23982),
-        ('Protein A [M+2H]2+', 22306),
-        ('Albumin Bovine [M+2H]2+', 33216),
-        ('Protein A [M+H]+', 44613),
-        ('Albumin Bovine [M+H]+', 66431),
-    ],
-    'ProtMix II Bruker - MALDI Neg Av':[
-        ('Trypsinogen [M+H]+', 23980),
-        ('Protein A [M+2H]2+', 22304),
-        ('Albumin Bovine [M+2H]2+', 33214),
-        ('Protein A [M+H]+', 44611),
-        ('Albumin Bovine [M+H]+', 66429),
-    ],
-    'Trypsin Promega (Porcine) - MALDI Pos Mo':[
+    'Trypsin (Porcine) - MALDI Pos Mo':[
         ('Trypsin (108-115) [M+H]+', 842.5094),
         ('Trypsin (209-216) [M+H]+', 906.5044),
         ('Trypsin (1-8) [M+H]+', 952.3894),
@@ -402,23 +350,6 @@ references = {
         ('Trypsin (78-97) [M+H]+', 2283.1802),
         ('Trypsin (179-208) [M+H]+', 3013.3237),
     ],
-    'Trypsin Roche (Bovine) - MALDI Pos Mo':[
-        ('Trypsin (112-119) [M+H]+', 805.4163),
-        ('Trypsin (160-169) [M+H]+', 1020.503),
-        ('Trypsin (229-237) [M+H]+', 1111.5605),
-        ('Trypsin (207-220) [M+H]+', 1433.7206),
-        ('Trypsin (70-89) [M+H]+', 2163.0564),
-        ('Trypsin (90-109) [M+H]+', 2273.1595),
-    ],
-    'Trypsin Roche (Porcine) - MALDI Pos Mo':[
-        ('Trypsin (108-115) [M+H]+', 842.5094),
-        ('Trypsin (134-147) [M+H]+', 1469.7305),
-        ('Trypsin (58-74) [M+H]+', 1940.9354),
-        ('Trypsin (116-133) [M+H]+', 1768.7993),
-        ('Trypsin (98-107) [M+H]+', 1045.5637),
-        ('Trypsin (58-77) [M+H]+', 2211.104),
-        ('Trypsin (148-157) [M+H]+', 1006.4874),
-    ],
     'HCCA Clusters - MALDI Pos Mo':[
         ('HCCA [M+H-H2O]+', 172.039304),
         ('HCCA [M+H]+', 190.049869),
@@ -528,79 +459,7 @@ references = {
         ('DHB [7M+K]+', 1117.149421),
         ('DHB [7M+K+Na-H2O]+', 1122.128077),
     ],
-    'PEG - MALDI Pos':[
-        ('C6H15O4 [M+H]+', 151.096485),
-        ('C6H14O4 [M+Na]+', 173.078430),
-        ('C8H19O5 [M+H]+', 195.122700),
-        ('C8H18O5 [M+Na]+', 217.104645),
-        ('C10H23O6 [M+H]+', 239.148915),
-        ('C10H22O6 [M+Na]+', 261.130860),
-        ('C12H27O7 [M+H]+', 283.175130),
-        ('C12H26O7 [M+Na]+', 305.157074),
-        ('C14H31O8 [M+H]+', 327.201344),
-        ('C14H30O8 [M+Na]+', 349.183289),
-        ('C16H35O9 [M+H]+', 371.227559),
-        ('C16H34O9 [M+Na]+', 393.209504),
-        ('C18H39O10 [M+H]+', 415.253774),
-        ('C18H38O10 [M+Na]+', 437.235719),
-        ('C20H43O11 [M+H]+', 459.279989),
-        ('C20H42O11 [M+Na]+', 481.261933),
-        ('C22H47O12 [M+H]+', 503.306203),
-        ('C22H46O12 [M+Na]+', 525.288148),
-        ('C24H51O13 [M+H]+', 547.332418),
-        ('C24H50O13 [M+Na]+', 569.314363),
-        ('C26H55O14 [M+H]+', 591.358633),
-        ('C26H54O14 [M+Na]+', 613.340578),
-        ('C28H59O15 [M+H]+', 635.384848),
-        ('C28H58O15 [M+Na]+', 657.366792),
-        ('C30H62O16 [M+Na]+', 701.393007),
-        ('C32H66O17 [M+Na]+', 745.419222),
-        ('C34H70O18 [M+Na]+', 789.445437),
-        ('C36H74O19 [M+Na]+', 833.471651),
-        ('C38H78O20 [M+Na]+', 877.497866),
-        ('C40H82O21 [M+Na]+', 921.524081),
-        ('C42H86O22 [M+Na]+', 965.550296),
-        ('C44H90O23 [M+Na]+', 1009.576510),
-        ('C46H94O24 [M+Na]+', 1053.602725),
-        ('C48H98O25 [M+Na]+', 1097.628940),
-        ('C50H102O26 [M+Na]+', 1141.655155),
-        ('C52H106O27 [M+Na]+', 1185.681369),
-        ('C54H110O28 [M+Na]+', 1229.707584),
-        ('C56H114O29 [M+Na]+', 1273.733799),
-        ('C58H118O30 [M+Na]+', 1317.760014),
-        ('C60H122O31 [M+Na]+', 1361.786228),
-        ('C62H126O32 [M+Na]+', 1405.812443),
-        ('C64H130O33 [M+Na]+', 1449.838658),
-        ('C66H134O34 [M+Na]+', 1493.864873),
-        ('C68H138O35 [M+Na]+', 1537.891087),
-        ('C70H142O36 [M+Na]+', 1581.917302),
-        ('C72H146O37 [M+Na]+', 1625.943517),
-        ('C74H150O38 [M+Na]+', 1669.969732),
-        ('C76H154O39 [M+Na]+', 1713.995946),
-        ('C78H158O40 [M+Na]+', 1758.022161),
-        ('C80H162O41 [M+Na]+', 1802.048376),
-        ('C82H166O42 [M+Na]+', 1846.074591),
-        ('C84H170O43 [M+Na]+', 1890.100805),
-        ('C86H174O44 [M+Na]+', 1934.127020),
-        ('C88H178O45 [M+Na]+', 1978.153235),
-        ('C90H182O46 [M+Na]+', 2022.179450),
-        ('C92H186O47 [M+Na]+', 2066.205664),
-        ('C94H190O48 [M+Na]+', 2110.231879),
-        ('C96H194O49 [M+Na]+', 2154.258094),
-        ('C98H198O50 [M+Na]+', 2198.284309),
-        ('C100H2O2O51 [M+Na]+', 2242.310523),
-        ('C104H210O53 [M+Na]+', 2330.362953),
-        ('C108H218O55 [M+Na]+', 2418.415382),
-        ('C112H226O57 [M+Na]+', 2506.467812),
-        ('C116H234O59 [M+Na]+', 2594.520241),
-        ('C120H242O61 [M+Na]+', 2682.572671),
-        ('C124H250O63 [M+Na]+', 2770.652100),
-        ('C128H258O65 [M+Na]+', 2858.677530),
-        ('C132H266O67 [M+Na]+', 2946.729959),
-        ('C136H274O69 [M+Na]+', 3034.782389),
-        ('C140H282O71 [M+Na]+', 3122.834828),
-    ],
-    'Contaminants - Trypsin In-Gel - MALDI Pos Mo':[
+    'In-Gel (Trypsin) - MALDI Pos Mo':[
         ('Keratin 10 [M+H]+', 1165.5853),
         ('Keratin 1/II [M+H]+', 1179.6010),
         ('Keratin 1/II [M+H]+', 1300.5302),
@@ -643,7 +502,7 @@ mascot = {
 # LOAD FUNCTIONS
 # --------------
 
-def loadPresets(path=os.path.join(config.confdir, 'presets.xml'), clear=False):
+def loadPresets(path=os.path.join(config.confdir, 'presets.xml'), clear=True, replace=True):
     """Parse processing presets XML and get data."""
     
     container = {}
@@ -734,14 +593,15 @@ def loadPresets(path=os.path.join(config.confdir, 'presets.xml'), clear=False):
     
     # update current lib
     for group in container:
-        if clear:
+        if container[group] and clear:
             presets[group].clear()
         for key in container[group]:
-            presets[group][key] = container[group][key]
+            if replace or not key in presets[group]:
+                presets[group][key] = container[group][key]
 # ----
 
 
-def loadReferences(path=os.path.join(config.confdir, 'references.xml'), clear=False):
+def loadReferences(path=os.path.join(config.confdir, 'references.xml'), clear=True):
     """Parse calibration references XML and get data."""
     
     container = {}
@@ -764,14 +624,14 @@ def loadReferences(path=os.path.join(config.confdir, 'references.xml'), clear=Fa
                     container[groupName].append((name, float(mass)))
     
     # update current lib
-    if clear:
+    if container and clear:
         references.clear()
     for group in container:
         references[group] = container[group]
 # ----
 
 
-def loadCompounds(path=os.path.join(config.confdir, 'compounds.xml'), clear=False):
+def loadCompounds(path=os.path.join(config.confdir, 'compounds.xml'), clear=True):
     """Parse compounds XML and get data."""
     
     container = {}
@@ -798,14 +658,14 @@ def loadCompounds(path=os.path.join(config.confdir, 'compounds.xml'), clear=Fals
                         pass
     
     # update current lib
-    if clear:
+    if container and clear:
         compounds.clear()
     for group in container:
         compounds[group] = container[group]
 # ----
 
 
-def loadMascot(path=os.path.join(config.confdir, 'mascot.xml'), clear=False):
+def loadMascot(path=os.path.join(config.confdir, 'mascot.xml'), clear=True, replace=True):
     """Parse mascot servers XML and get data."""
     
     container = {}
@@ -829,7 +689,7 @@ def loadMascot(path=os.path.join(config.confdir, 'mascot.xml'), clear=False):
             _getParams(serverTag, container[name])
     
     # update current lib
-    if clear:
+    if container and clear:
         mascot.clear()
     for server in container:
         mascot[server] = container[server]
@@ -1003,7 +863,7 @@ def saveCompounds(path=os.path.join(config.confdir, 'compounds.xml')):
     for group in sorted(compounds.keys()):
         buff += '  <group name="%s">\n' % (_escape(group))
         for name, compound in sorted(compounds[group].items()):
-            buff += '    <compound name="%s" formula="%s">%s</compound>\n' % (_escape(name), compound.rawFormula, _escape(compound.description))
+            buff += '    <compound name="%s" formula="%s">%s</compound>\n' % (_escape(name), compound.expression, _escape(compound.description))
         buff += '  </group>\n\n'
     
     buff += '</mMassCompounds>'
