@@ -24,6 +24,7 @@ import wx
 from ids import *
 import images
 import config
+import mspy
 
 
 # GUI CONSTANTS
@@ -49,6 +50,7 @@ TOOLBAR_LSPACE = 0
 TOOLBAR_RSPACE = 10
 TOOLBAR_TOOLSIZE = (-1,-1)
 CONTROLBAR_HEIGHT = 32
+CONTROLBAR_DOUBLE_HEIGHT = 61
 CONTROLBAR_LSPACE = 10
 CONTROLBAR_RSPACE = 10
 BOTTOMBAR_HEIGHT = 22
@@ -58,6 +60,7 @@ BOTTOMBAR_TOOLSIZE = (-1,-1)
 SMALL_COMBO_HEIGHT = -1
 SMALL_BUTTON_HEIGHT = 22
 SMALL_TEXTCTRL_HEIGHT = -1
+SMALL_SEARCH_HEIGHT = -1
 BUTTON_SIZE_CORRECTION = 0
 
 COMBO_HEIGHT = -1
@@ -98,21 +101,21 @@ if wx.Platform == '__WXMAC__':
     GAUGE_HEIGHT = 11
     GAUGE_SPACE = 15
     
-    MAIN_TOOLBAR_TOOLSIZE = (30,22)
+    MAIN_TOOLBAR_TOOLSIZE = (30,23)
     MAIN_TOOLBAR_STYLE = wx.TB_FLAT|wx.TB_NODIVIDER|wx.TB_HORIZONTAL|wx.TB_TEXT
     
     TOOLBAR_HEIGHT = 38
     TOOLBAR_LSPACE = 15
     TOOLBAR_RSPACE = 15
-    CONTROLBAR_HEIGHT = 32
     CONTROLBAR_LSPACE = 15
     CONTROLBAR_RSPACE = 15
-    BOTTOMBAR_HEIGHT = 32
+    BOTTOMBAR_HEIGHT = 33
     BOTTOMBAR_LSPACE = 10
     BOTTOMBAR_RSPACE = 10
     SMALL_COMBO_HEIGHT = 22
     SMALL_BUTTON_HEIGHT = -1
     SMALL_TEXTCTRL_HEIGHT = 18
+    SMALL_SEARCH_HEIGHT = 22
     BUTTON_SIZE_CORRECTION = -3
     
     COMBO_HEIGHT = 22
@@ -147,6 +150,7 @@ if wx.Platform == '__WXMAC__':
 elif wx.Platform == '__WXMSW__':
     SMALL_COMBO_HEIGHT = 22
     SMALL_BUTTON_HEIGHT = 22
+    SMALL_SEARCH_HEIGHT = 22
     
     DASHED_LINE = wx.DOT
 
@@ -155,7 +159,6 @@ elif wx.Platform == '__WXGTK__':
     SMALL_FONT_SIZE = 10
     NORMAL_FONT_SIZE = 11
     SASH_SIZE = 6
-    SASH_COLOUR = (237,236,235)
     
     TOOLBAR_TOOLSIZE = (32,26)
     BOTTOMBAR_HEIGHT = 28
@@ -163,6 +166,7 @@ elif wx.Platform == '__WXGTK__':
     SMALL_COMBO_HEIGHT = 25
     SMALL_BUTTON_HEIGHT = 25
     SMALL_TEXTCTRL_HEIGHT = 25
+    SMALL_SEARCH_HEIGHT = 25
     
     DOCTREE_BULLETSIZE = 4
     DOCTREE_STYLE = wx.TR_DEFAULT_STYLE|wx.TR_HAS_BUTTONS|wx.TR_HIDE_ROOT|wx.SUNKEN_BORDER
@@ -214,7 +218,7 @@ class bgrPanel(wx.Panel):
         
         # create paint surface
         dc = wx.PaintDC(self)
-        dc.Clear()
+        #dc.Clear()
         
         # tile/wallpaper the image across the canvas
         for x in range(0, self.GetSize()[0], self.image.GetWidth()):
@@ -633,6 +637,37 @@ class scrollTextCtrl(wx.TextCtrl):
     
 
 
+class formulaCtrl(wx.TextCtrl):
+    """TextCtrl to molecular formulae."""
+    
+    def __init__(self, parent, id=-1, value="", pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, validator=wx.DefaultValidator):
+        wx.TextCtrl.__init__(self, parent, id, value, pos, size, style, validator)
+        self.Bind(wx.EVT_TEXT, self._onText)
+    # ----
+    
+    
+    def _onText(self, evt):
+        """Check current formula."""
+        evt.Skip()
+        wx.CallAfter(self._checkFormula)
+    # ----
+    
+    
+    def _checkFormula(self):
+        """Check current formula."""
+        
+        try:
+            formula = mspy.compound(self.GetValue())
+            self.SetBackgroundColour(wx.NullColour)
+        except:
+            self.SetBackgroundColour((250,100,100))
+        
+        self.Refresh()
+    # ----
+    
+    
+
+
 class gauge(wx.Gauge):
     """Gauge."""
     
