@@ -406,20 +406,55 @@ class panelCompoundsSearch(wx.MiniFrame):
     
     def onItemActivated(self, evt):
         """Show isotopic pattern for selected compound."""
+        self.onItemSendToMassCalculator(evt)
+    # ----
+    
+    
+    def onItemSendToMassCalculator(self, evt):
+        """Show isotopic pattern for selected compound."""
         
-        # get formula and charge
-        item = self.currentCompounds[evt.GetData()]
-        formula = item[4]
-        charge = item[2]
+        # get data
+        selected = self.compoundsList.getSelected()
+        if selected:
+            index = self.compoundsList.GetItemData(selected[0])
+            formula = self.currentCompounds[index][4]
+            charge = self.currentCompounds[index][2]
+            radical = self.currentCompounds[index][3]
+        else:
+            wx.Bell()
+            return
         
-        # send to masscalc
-        if item[3] == 'radical':
+        # send data to masscalc
+        if radical == 'radical':
             self.parent.onToolsMassCalculator(formula=formula, charge=charge, agentFormula='e', agentCharge=-1)
         else:
             self.parent.onToolsMassCalculator(formula=formula, charge=charge, agentFormula='H', agentCharge=1)
     # ----
     
     
+    def onItemCopyFormula(self, evt):
+        """Copy selected compound formula into clipboard."""
+        
+        # get data
+        selected = self.compoundsList.getSelected()
+        if selected:
+            index = self.compoundsList.GetItemData(selected[0])
+            formula = self.currentCompounds[index][4]
+        else:
+            wx.Bell()
+            return
+        
+        # make text object for data
+        obj = wx.TextDataObject()
+        obj.SetText(formula)
+        
+        # paste to clipboard
+        if wx.TheClipboard.Open():
+            wx.TheClipboard.SetData(obj)
+            wx.TheClipboard.Close()
+    # ----
+    
+    
     def onListKey(self, evt):
         """Export list if Ctrl+C."""
         
@@ -445,7 +480,10 @@ class panelCompoundsSearch(wx.MiniFrame):
         menu.Append(ID_listViewMatched, "Show Matched Only", "", wx.ITEM_RADIO)
         menu.Append(ID_listViewUnmatched, "Show Unmatched Only", "", wx.ITEM_RADIO)
         menu.AppendSeparator()
-        menu.Append(ID_listCopy, "Copy All")
+        menu.Append(ID_listSendToMassCalculator, "Show Isotopic Pattern", "")
+        menu.AppendSeparator()
+        menu.Append(ID_listCopyFormula, "Copy Formula")
+        menu.Append(ID_listCopy, "Copy List")
         
         # check item
         if self._compoundsFilter == 1:
@@ -459,6 +497,8 @@ class panelCompoundsSearch(wx.MiniFrame):
         self.Bind(wx.EVT_MENU, self.onListFilter, id=ID_listViewAll)
         self.Bind(wx.EVT_MENU, self.onListFilter, id=ID_listViewMatched)
         self.Bind(wx.EVT_MENU, self.onListFilter, id=ID_listViewUnmatched)
+        self.Bind(wx.EVT_MENU, self.onItemSendToMassCalculator, id=ID_listSendToMassCalculator)
+        self.Bind(wx.EVT_MENU, self.onItemCopyFormula, id=ID_listCopyFormula)
         self.Bind(wx.EVT_MENU, self.onListCopy, id=ID_listCopy)
         
         # show menu
@@ -787,12 +827,12 @@ class panelCompoundsSearch(wx.MiniFrame):
                     
                     # main ion
                     mz = compound.mz(z*polarity)[config.compounds['massType']]
-                    self.currentCompounds.append([name, mz, z*polarity, None, compound.rawFormula, None, []])
+                    self.currentCompounds.append([name, mz, z*polarity, None, compound.expression, None, []])
                     
                     # radicals
                     if config.compounds['radicals']:
                         mz = compound.mz(z*polarity, agentFormula='e', agentCharge=-1)[config.compounds['massType']]
-                        self.currentCompounds.append([name, mz, z*polarity, 'radical', compound.rawFormula, None, []])
+                        self.currentCompounds.append([name, mz, z*polarity, 'radical', compound.expression, None, []])
                     
                     mspy.CHECK_FORCE_QUIT()
                     
@@ -800,14 +840,14 @@ class panelCompoundsSearch(wx.MiniFrame):
                     for item in config.compounds['adducts']:
                         
                         if item in ('Na', 'K', 'Li', 'NH4', 'ACN', 'MeOH'):
-                            formula = '%s(%s)(H-1)' % (compound.rawFormula, adducts[item])
+                            formula = '%s(%s)(H-1)' % (compound.expression, adducts[item])
                         elif item in ('-H2O'):
-                            formula = '%s(%s)' % (compound.rawFormula, adducts[item])
+                            formula = '%s(%s)' % (compound.expression, adducts[item])
                         
                         formula = mspy.compound(formula)
                         if formula.isvalid():
                             mz = formula.mz(z*polarity)[config.compounds['massType']]
-                            self.currentCompounds.append([name, mz, z*polarity, item, formula.rawFormula, None, []])
+                            self.currentCompounds.append([name, mz, z*polarity, item, formula.expression, None, []])
                     
                     mspy.CHECK_FORCE_QUIT()
                     
@@ -819,15 +859,15 @@ class panelCompoundsSearch(wx.MiniFrame):
                                     
                                     if item2 in ('ACN', 'MeOH'):
                                         adduct = '%s+%s' % (item1, item2)
-                                        formula = '%s(%s)(%s)(H-2)' % (compound.rawFormula, adducts[item1], adducts[item2])
+                                        formula = '%s(%s)(%s)(H-2)' % (compound.expression, adducts[item1], adducts[item2])
                                     elif item2 in ('-H2O'):
                                         adduct = '%s%s' % (item1, item2)
-                                        formula = '%s(%s)(%s)(H-1)' % (compound.rawFormula, adducts[item1], adducts[item2])
+                                        formula = '%s(%s)(%s)(H-1)' % (compound.expression, adducts[item1], adducts[item2])
                                     
                                     formula = mspy.compound(formula)
                                     if formula.isvalid():
                                         mz = formula.mz(z*polarity)[config.compounds['massType']]
-                                        self.currentCompounds.append([name, mz, z*polarity, adduct, formula.rawFormula, None, []])
+                                        self.currentCompounds.append([name, mz, z*polarity, adduct, formula.expression, None, []])
         
         # task canceled
         except mspy.ForceQuit:
