@@ -746,7 +746,7 @@ class panelDocumentExport(wx.MiniFrame):
                 if 'int' in config.export['peaklistColumns']:
                     line += str(peak.intensity) + separator
                 if 'rel' in config.export['peaklistColumns']:
-                    line += str(peak.relIntensity*100) + separator
+                    line += str(peak.ri*100) + separator
                 if 'sn' in config.export['peaklistColumns']:
                     line += str(peak.sn) + separator
                 if 'z' in config.export['peaklistColumns']:
