@@ -151,6 +151,9 @@ class panelDocumentInfo(wx.MiniFrame):
         self.date_value = wx.TextCtrl(panel, -1, "", size=(300, -1))
         self.date_value.Bind(wx.EVT_TEXT, self.onSave)
         
+        path_label = wx.StaticText(panel, -1, "Path:")
+        self.path_value = wx.TextCtrl(panel, -1, "", size=(300, -1))
+        
         # pack elements
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         grid.Add(title_label, (0,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
@@ -165,6 +168,8 @@ class panelDocumentInfo(wx.MiniFrame):
         grid.Add(self.instrument_value, (4,1))
         grid.Add(date_label, (5,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.date_value, (5,1))
+        grid.Add(path_label, (6,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
+        grid.Add(self.path_value, (6,1))
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -442,6 +447,7 @@ class panelDocumentInfo(wx.MiniFrame):
         # clear previous values
         self.title_value.ChangeValue('')
         self.date_value.ChangeValue('')
+        self.path_value.ChangeValue('')
         self.operator_value.ChangeValue('')
         self.contact_value.ChangeValue('')
         self.institution_value.ChangeValue('')
@@ -460,6 +466,7 @@ class panelDocumentInfo(wx.MiniFrame):
         if self.currentDocument:
             self.title_value.ChangeValue(document.title)
             self.date_value.ChangeValue(document.date)
+            self.path_value.ChangeValue(document.path)
             self.operator_value.ChangeValue(document.operator)
             self.contact_value.ChangeValue(document.contact)
             self.institution_value.ChangeValue(document.institution)
