@@ -215,6 +215,7 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_documentDuplicate, "Duplicate Document")
             menu.AppendSeparator()
             menu.Append(ID_documentClose, "Close Document")
+            menu.Append(ID_documentCloseAll, "Close All Documents")
             
             if config.spectrum['normalize']:
                 menu.Enable(ID_documentOffset, False)
@@ -232,7 +233,9 @@ class panelDocuments(wx.Panel):
         
         elif itemType == 'annotation':
             menu.Append(ID_documentAnnotationEdit, "Edit Annotation...")
-            menu.Append(ID_documentAnnotationPattern, "Show Isotopic Pattern...")
+            menu.AppendSeparator()
+            menu.Append(ID_documentAnnotationSendToMassCalculator, "Show Isotopic Pattern...")
+            menu.Append(ID_documentAnnotationSendToEnvelopeFit, "Send to Envelope Fit...")
             menu.AppendSeparator()
             menu.Append(ID_documentAnnotationsCalibrateBy, "Calibrate by Annotations...")
             menu.AppendSeparator()
@@ -240,7 +243,8 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_documentAnnotationsDelete, "Delete All Annotations")
             
             if not itemData.formula:
-                menu.Enable(ID_documentAnnotationPattern, False)
+                menu.Enable(ID_documentAnnotationSendToMassCalculator, False)
+                menu.Enable(ID_documentAnnotationSendToEnvelopeFit, False)
         
         elif itemType == 'sequence':
             menu.Append(ID_sequenceEditor, "Edit Sequence...")
@@ -250,6 +254,9 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_sequenceFragment, "Fragment Peptide...")
             menu.Append(ID_sequenceSearch, "Mass Search...")
             menu.AppendSeparator()
+            menu.Append(ID_sequenceSendToMassCalculator, "Show Isotopic Pattern...")
+            menu.Append(ID_sequenceSendToEnvelopeFit, "Send to Envelope Fit...")
+            menu.AppendSeparator()
             menu.Append(ID_sequenceMatchesCalibrateBy, "Calibrate by Matches...")
             menu.AppendSeparator()
             menu.Append(ID_sequenceMatchesDelete, "Delete All Matches")
@@ -261,7 +268,9 @@ class panelDocuments(wx.Panel):
         
         elif itemType == 'match':
             menu.Append(ID_sequenceMatchEdit, "Edit Match...")
-            menu.Append(ID_sequenceMatchPattern, "Show Isotopic Pattern...")
+            menu.AppendSeparator()
+            menu.Append(ID_sequenceMatchSendToMassCalculator, "Show Isotopic Pattern...")
+            menu.Append(ID_sequenceMatchSendToEnvelopeFit, "Send to Envelope Fit...")
             menu.AppendSeparator()
             menu.Append(ID_sequenceMatchesCalibrateBy, "Calibrate by Matches...")
             menu.AppendSeparator()
@@ -269,7 +278,8 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_sequenceMatchesDelete, "Delete All Matches")
             
             if not itemData.formula:
-                menu.Enable(ID_documentAnnotationPattern, False)
+                menu.Enable(ID_sequenceMatchSendToMassCalculator, False)
+                menu.Enable(ID_sequenceMatchSendToEnvelopeFit, False)
         
         # bind events
         self.Bind(wx.EVT_MENU, self.parent.onDocumentInfo, id=ID_documentInfo)
@@ -280,9 +290,11 @@ class panelDocuments(wx.Panel):
         self.Bind(wx.EVT_MENU, self.parent.onDocumentNotationsDelete, id=ID_documentNotationsDelete)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentDuplicate, id=ID_documentDuplicate)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentClose, id=ID_documentClose)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentCloseAll, id=ID_documentCloseAll)
         
         self.Bind(wx.EVT_MENU, self.onNotationEdit, id=ID_documentAnnotationEdit)
-        self.Bind(wx.EVT_MENU, self.onNotationPattern, id=ID_documentAnnotationPattern)
+        self.Bind(wx.EVT_MENU, self.onSendToMassCalculator, id=ID_documentAnnotationSendToMassCalculator)
+        self.Bind(wx.EVT_MENU, self.onSendToEnvelopeFit, id=ID_documentAnnotationSendToEnvelopeFit)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentAnnotationsCalibrateBy, id=ID_documentAnnotationsCalibrateBy)
         self.Bind(wx.EVT_MENU, self.onNotationDelete, id=ID_documentAnnotationDelete)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentAnnotationsDelete, id=ID_documentAnnotationsDelete)
@@ -293,10 +305,13 @@ class panelDocuments(wx.Panel):
         self.Bind(wx.EVT_MENU, self.parent.onToolsSequence, id=ID_sequenceDigest)
         self.Bind(wx.EVT_MENU, self.parent.onToolsSequence, id=ID_sequenceFragment)
         self.Bind(wx.EVT_MENU, self.parent.onToolsSequence, id=ID_sequenceSearch)
+        self.Bind(wx.EVT_MENU, self.onSendToMassCalculator, id=ID_sequenceSendToMassCalculator)
+        self.Bind(wx.EVT_MENU, self.onSendToEnvelopeFit, id=ID_sequenceSendToEnvelopeFit)
         self.Bind(wx.EVT_MENU, self.parent.onSequenceDelete, id=ID_sequenceDelete)
         
         self.Bind(wx.EVT_MENU, self.onNotationEdit, id=ID_sequenceMatchEdit)
-        self.Bind(wx.EVT_MENU, self.onNotationPattern, id=ID_sequenceMatchPattern)
+        self.Bind(wx.EVT_MENU, self.onSendToMassCalculator, id=ID_sequenceMatchSendToMassCalculator)
+        self.Bind(wx.EVT_MENU, self.onSendToEnvelopeFit, id=ID_sequenceMatchSendToEnvelopeFit)
         self.Bind(wx.EVT_MENU, self.parent.onSequenceMatchesCalibrateBy, id=ID_sequenceMatchesCalibrateBy)
         self.Bind(wx.EVT_MENU, self.onNotationDelete, id=ID_sequenceMatchDelete)
         self.Bind(wx.EVT_MENU, self.parent.onSequenceMatchesDelete, id=ID_sequenceMatchesDelete)
@@ -344,7 +359,7 @@ class panelDocuments(wx.Panel):
         seqIndex = self._getSequenceIndex(item)
         self.parent.onSequenceSelected(seqIndex)
         
-        # highlight matches and annotations
+        # update notation marks
         self.parent.updateNotationMarks()
         
         # highlight mass of selected match or annotation
@@ -397,7 +412,9 @@ class panelDocuments(wx.Panel):
         # popup menu
         menu = wx.Menu()
         menu.Append(ID_sequenceNew, "New Sequence...")
+        menu.AppendSeparator()
         menu.Append(ID_documentNew, "New Document")
+        menu.Append(ID_documentNewFromClipboard, "New from Clipboard")
         menu.AppendSeparator()
         menu.Append(ID_documentOpen, "Open Document...")
         
@@ -406,6 +423,7 @@ class panelDocuments(wx.Panel):
         # set events
         self.Bind(wx.EVT_MENU, self.parent.onSequenceNew, id=ID_sequenceNew)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentNew, id=ID_documentNew)
+        self.Bind(wx.EVT_MENU, self.parent.onDocumentNewFromClipboard, id=ID_documentNewFromClipboard)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentOpen, id=ID_documentOpen)
         
         self.PopupMenu(menu)
@@ -507,22 +525,6 @@ class panelDocuments(wx.Panel):
     # ----
     
     
-    def onNotationPattern(self, evt=None):
-        """Show isotopic pattern for selected annotation or sequence match."""
-        
-        # get selected item
-        item = self.documentTree.GetSelection()
-        itemData = self.documentTree.GetPyData(item)
-        
-        # show profile
-        if itemData.formula:
-            if itemData.radical:
-                self.parent.onToolsMassCalculator(formula=itemData.formula, charge=itemData.charge, agentFormula='e', agentCharge=-1)
-            else:
-                self.parent.onToolsMassCalculator(formula=itemData.formula, charge=itemData.charge, agentFormula='H', agentCharge=1)
-    # ----
-    
-    
     def onNotationDelete(self, evt=None):
         """Delete selected annotation or sequence match."""
         
@@ -544,6 +546,50 @@ class panelDocuments(wx.Panel):
     # ----
     
     
+    def onSendToMassCalculator(self, evt=None):
+        """Send selected item to Mass Calculator panel."""
+        
+        # get selected item
+        item = self.documentTree.GetSelection()
+        itemType = self.documentTree.getItemType(item)
+        itemData = self.documentTree.GetPyData(item)
+        
+        # send data to Mass Calculator
+        if itemType == 'sequence':
+            self.parent.onToolsMassCalculator(formula=itemData.formula())
+        elif itemType in ('annotation', 'match'):
+            if itemData.radical:
+                self.parent.onToolsMassCalculator(formula=itemData.formula, charge=itemData.charge, agentFormula='e', agentCharge=-1)
+            else:
+                self.parent.onToolsMassCalculator(formula=itemData.formula, charge=itemData.charge, agentFormula='H', agentCharge=1)
+    # ----
+    
+    
+    def onSendToEnvelopeFit(self, evt=None):
+        """Send selected item to envelope fit panel."""
+        
+        # get selected item
+        item = self.documentTree.GetSelection()
+        itemType = self.documentTree.getItemType(item)
+        itemData = self.documentTree.GetPyData(item)
+        
+        # send data to envelope fit
+        if itemType == 'sequence':
+            self.parent.onToolsEnvelopeFit(sequence=itemData)
+        
+        elif itemType == 'annotation':
+            self.parent.onToolsEnvelopeFit(formula=itemData.formula, charge=itemData.charge)
+        
+        elif itemType == 'match':
+            
+            scale = None
+            if itemData.sequenceRange and config.envfit['loss'] == 'H' and config.envfit['gain'] == 'H{2}':
+                scale = [0, itemData.sequenceRange[1]-itemData.sequenceRange[0]]
+            
+            self.parent.onToolsEnvelopeFit(formula=itemData.formula, charge=itemData.charge, scale=scale)
+    # ----
+    
+    
     
     # DOCUMENT
     
@@ -553,6 +599,7 @@ class panelDocuments(wx.Panel):
         # deselect all documents
         if docIndex == None:
             self.documentTree.Unselect()
+            self.parent.onDocumentSelected(None)
             return
         
         # get item
