@@ -806,13 +806,7 @@ class panelMascot(wx.MiniFrame):
             self.search_butt.Enable(False)
         
         # fit layout
-        self.Layout()
-        self.mainSizer.Fit(self)
-        
-        # force resize
-        size = self.GetSize()
-        self.SetSize((size[0], size[1]+1))
-        self.SetSize(size)
+        mwx.layout(self, self.mainSizer)
     # ----
     
     
