@@ -108,9 +108,10 @@ class panelMassCalculator(wx.MiniFrame):
         
         # make compound fields
         compound_label = wx.StaticText(panel, -1, "Formula:")
-        self.compound_value = wx.TextCtrl(panel, -1, "", size=(250, -1))
+        self.compound_value = mwx.formulaCtrl(panel, -1, "", size=(250, -1), style=wx.TE_PROCESS_ENTER)
         compound_label.SetFont(wx.SMALL_FONT)
         self.compound_value.Bind(wx.EVT_TEXT, self.onCompoundChanged)
+        self.compound_value.Bind(wx.EVT_TEXT_ENTER, self.onCompoundChanged)
         
         # make save button
         self.save_butt = wx.Button(panel, -1, "Save", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
@@ -268,7 +269,7 @@ class panelMassCalculator(wx.MiniFrame):
         
         patternShift_label = wx.StaticText(ctrlPanel, -1, "Shift:")
         patternShift_label.SetFont(wx.SMALL_FONT)
-        self.patternShift_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(0), step=0.001, digits=3, limits=(-1.,1.), size=(55, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternShift_value = mwx.scrollTextCtrl(ctrlPanel, -1, "0", step=0.001, digits=3, limits=(-1.,1.), size=(55, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternShift_value.SetFont(wx.SMALL_FONT)
         self.patternShift_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
@@ -338,16 +339,18 @@ class panelMassCalculator(wx.MiniFrame):
         self.patternCanvas.setProperties(xLabel='m/z')
         self.patternCanvas.setProperties(yLabel='a.i.')
         self.patternCanvas.setProperties(showLegend=True)
-        self.patternCanvas.setProperties(showPosBar=False)
+        self.patternCanvas.setProperties(showPosBar=True)
         self.patternCanvas.setProperties(showIntBar=True)
+        self.patternCanvas.setProperties(posBarHeight=6)
         self.patternCanvas.setProperties(intBarHeight=6)
         self.patternCanvas.setProperties(showGel=False)
-        self.patternCanvas.setProperties(checkLimits=False)
+        self.patternCanvas.setProperties(checkLimits=True)
         self.patternCanvas.setProperties(autoScaleY=True)
         self.patternCanvas.setProperties(overlapLabels=False)
         self.patternCanvas.setProperties(xPosDigits=5)
         self.patternCanvas.setProperties(yPosDigits=2)
         self.patternCanvas.setProperties(distanceDigits=5)
+        self.patternCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.patternCanvas.setProperties(reverseDrawing=True)
         self.patternCanvas.setLMBFunction('xDistance')
         self.patternCanvas.setMFunction('cross')
@@ -445,6 +448,9 @@ class panelMassCalculator(wx.MiniFrame):
     def onCompoundChanged(self, evt=None):
         """Recalc all if compound changed."""
         
+        if evt != None:
+            evt.Skip()
+        
         # get all params
         if not self.getParams():
             self.currentCompound = None
@@ -789,27 +795,27 @@ class panelMassCalculator(wx.MiniFrame):
         
         # add main profile spectrum to container
         labelFont = wx.Font(config.spectrum['labelFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
-        spectrum = mspy.plot.spectrum(self.currentPatternScan, \
-            legend=legend, \
-            spectrumColour=(16,71,185), \
-            tickColour=(255,0,0), \
-            showPoints=False, \
-            showLabels=True, \
-            showTicks=True, \
-            labelDigits=config.main['mzDigits'], \
-            labelBgr=True, \
-            labelAngle=90,
-            labelFont=labelFont \
+        spectrum = mspy.plot.spectrum(self.currentPatternScan,
+            legend = legend,
+            spectrumColour = (16,71,185),
+            tickColour = (255,0,0),
+            showPoints = False,
+            showLabels = True,
+            showTicks = True,
+            labelDigits = config.main['mzDigits'],
+            labelBgr = True,
+            labelAngle = 90,
+            labelFont = labelFont
         )
         container.append(spectrum)
         
         # add individual peaks to container
         for peak in self.currentPatternPeaks:
-            spectrum = mspy.plot.points(peak, \
-                lineColour=(50,140,0), \
-                showLines=True, \
-                showPoints=False, \
-                exactFit=True \
+            spectrum = mspy.plot.points(peak,
+                lineColour = (50,140,0),
+                showLines = True,
+                showPoints = False,
+                exactFit = True
             )
             container.append(spectrum)
         
@@ -817,6 +823,9 @@ class panelMassCalculator(wx.MiniFrame):
         if not rescale:
             xAxis = self.patternCanvas.getCurrentXRange()
             yAxis = self.patternCanvas.getCurrentYRange()
+            if xAxis == (0,1) or yAxis == (0,1):
+                xAxis = None
+                yAxis = None
         else:
             xAxis = None
             yAxis = None
@@ -902,24 +911,24 @@ class panelMassCalculator(wx.MiniFrame):
                 charge = self.currentIon[3]
             
             # calculate compound pattern
-            pattern = self.currentCompound.pattern(\
-                fwhm=min(0.9, config.masscalc['patternFwhm']), \
-                threshold=config.masscalc['patternThreshold'], \
-                charge=charge, \
-                agentFormula=config.masscalc['ionseriesAgent'], \
-                agentCharge=config.masscalc['ionseriesAgentCharge'] \
+            pattern = self.currentCompound.pattern(
+                fwhm = min(0.9, config.masscalc['patternFwhm']),
+                threshold = config.masscalc['patternThreshold'],
+                charge = charge,
+                agentFormula = config.masscalc['ionseriesAgent'],
+                agentCharge = config.masscalc['ionseriesAgentCharge']
             )
             
             # make peaklist from pattern
             peaklist = []
             for isotope in pattern:
                 ai = isotope[1]*(config.masscalc['patternIntensity'] - config.masscalc['patternBaseline']) + config.masscalc['patternBaseline']
-                peak = mspy.peak( \
-                    mz=isotope[0], \
-                    ai=ai, \
-                    base=config.masscalc['patternBaseline'], \
-                    fwhm=config.masscalc['patternFwhm'], \
-                    charge=charge \
+                peak = mspy.peak(
+                    mz = isotope[0],
+                    ai = ai,
+                    base = config.masscalc['patternBaseline'],
+                    fwhm = config.masscalc['patternFwhm'],
+                    charge = charge
                 )
                 peaklist.append(peak)
             peaklist = mspy.peaklist(peaklist)
@@ -927,11 +936,11 @@ class panelMassCalculator(wx.MiniFrame):
             # make peaks
             self.currentPatternPeaks = []
             for isotope in peaklist:
-                peak = mspy.gaussian(\
-                    mz=isotope.mz, \
-                    ai=isotope.ai, \
-                    base=isotope.base, \
-                    fwhm=isotope.fwhm \
+                peak = mspy.gaussian(
+                    mz = isotope.mz,
+                    ai = isotope.ai,
+                    base = isotope.base,
+                    fwhm = isotope.fwhm
                 )
                 self.currentPatternPeaks.append(peak)
             
