@@ -245,6 +245,7 @@ class panelMatch(wx.MiniFrame):
         self.errorCanvas.setProperties(autoScaleY=False)
         self.errorCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.errorCanvas.setProperties(yPosDigits=2)
+        self.errorCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.errorCanvas.setProperties(reverseDrawing=True)
         self.errorCanvas.setMFunction('cross')
         
@@ -571,9 +572,9 @@ class panelMatch(wx.MiniFrame):
                 errorCol = 5
                 matchObject = doc.match
             elif self.currentModule == 'fragment':
-                massCol = 3
-                chargeCol = 4
-                errorCol = 6
+                massCol = 2
+                chargeCol = 3
+                errorCol = 5
                 matchObject = doc.match
             elif self.currentModule == 'compounds':
                 massCol = 1
@@ -757,12 +758,31 @@ class panelMatch(wx.MiniFrame):
         label = 'Number of %s matched' % itemName
         self.currentSummary.append((label, sumMatched))
         
+        # get matched intensity
+        totalInt = 0
+        buff = {}
+        for peak in self.currentPeaklist:
+            totalInt += peak.intensity
+            buff[round(peak.mz, 6)] = peak.intensity
+        matchedInt = 0
+        for item in self.currentData:
+            for n in item[-1]:
+                mz = round(n.mz,6)
+                if mz in buff:
+                    matchedInt += buff[mz]
+                    del buff[mz]
+        if totalInt:
+            value = '%0.f %s' % ((100*matchedInt/totalInt), '%')
+        else:
+            value = '0 %'
+        self.currentSummary.append(('Intensity matched', value))
+        
         # get sequence coverage
         if self.currentModule == 'digest':
             sumPeptides = []
             for item in self.currentData:
                 if item[-1]:
-                    sumPeptides.append(item[0])
+                    sumPeptides.append([item[6].history[-1][1]+1, item[6].history[-1][2]])
             coverage = mspy.coverage(sumPeptides, self.currentSummaryData['sequenceLength'])
             value = '%0.f %s' % (coverage, '%')
             self.currentSummary.append(('Sequence length', self.currentSummaryData['sequenceLength']))
@@ -774,18 +794,29 @@ class panelMatch(wx.MiniFrame):
             
             series = {}
             for item in self.currentData:
-                if item[0][:3] == 'int':
+                frag = item[6]
+                
+                if not frag.fragmentSerie in ('a','b','c','x','y','z','n-ladder','c-ladder'):
                     continue
-                if not item[0] in series:
-                    series[item[0]] = []
+                elif 'break' in [x[0] for x in frag.history]:
+                    continue
+                
+                name = frag.fragmentSerie
+                for loss in frag.fragmentLosses:
+                    name += ' -'+loss
+                for gain in frag.fragmentGains:
+                    name += ' +'+gain
+                
+                if not name in series:
+                    series[name] = []
                 if item[-1]:
-                    series[item[0]].append(item[1])
+                    series[name].append(frag.fragmentIndex)
                 
             for serie in sorted(series.keys()):
                 matches = series[serie]
                 matches.sort()
                 value = ', '.join(str(n) for n in matches)
-                label = 'Ion serie "%s" matches' % serie
+                label = 'Ion serie matches for "%s"' % serie
                 self.currentSummary.append((label, value))
     # ----
     
