@@ -425,6 +425,12 @@ class panelPeakDifferences(wx.MiniFrame):
     def searchAll(self):
         """Search differences for specified value, aminoacids or dipeptides."""
         
+        # get amino acids
+        aminoacids = []
+        for abbr in mspy.monomers:
+            if mspy.monomers[abbr].category == '_InternalAA':
+                aminoacids.append(abbr)
+        
         # get maxima
         aaMin = 0
         aaMax = 0
@@ -432,8 +438,8 @@ class panelPeakDifferences(wx.MiniFrame):
         dipMax = 0
         if config.differences['aminoacids'] or config.differences['dipeptides']:
             masses = []
-            for aa in mspy.aminoacids:
-                masses.append(mspy.aminoacids[aa].mass[config.differences['massType']])
+            for aa in aminoacids:
+                masses.append(mspy.monomers[aa].mass[config.differences['massType']])
             aaMin = min(masses) - config.differences['tolerance']
             aaMax = max(masses) + config.differences['tolerance']
             dipMin = min(masses)*2 - config.differences['tolerance']
@@ -467,8 +473,8 @@ class panelPeakDifferences(wx.MiniFrame):
                 
                 # search for aminoacids
                 if not matched and config.differences['aminoacids'] and aaMin <= diff <= aaMax:
-                    for aa in mspy.aminoacids:
-                        if diffMin <= mspy.aminoacids[aa].mass[config.differences['massType']] <= diffMax:
+                    for aa in aminoacids:
+                        if diffMin <= mspy.monomers[aa].mass[config.differences['massType']] <= diffMax:
                             self.currentDifferences[x][y][1] = 'amino'
                             matched = True
                 
@@ -486,6 +492,12 @@ class panelPeakDifferences(wx.MiniFrame):
         
         self.currentMatches = []
         
+        # get amino acids
+        aminoacids = []
+        for abbr in mspy.monomers:
+            if mspy.monomers[abbr].category == '_InternalAA':
+                aminoacids.append(abbr)
+        
         # search for value
         if self.difference:
             error = diff - self.difference
@@ -494,8 +506,8 @@ class panelPeakDifferences(wx.MiniFrame):
         
         # search for aminoacids
         if config.differences['aminoacids']:
-            for aa in mspy.aminoacids:
-                error = diff - mspy.aminoacids[aa].mass[config.differences['massType']]
+            for aa in aminoacids:
+                error = diff - mspy.monomers[aa].mass[config.differences['massType']]
                 if abs(error) <= config.differences['tolerance']:
                     self.currentMatches.append([aa, error])
         
@@ -531,16 +543,21 @@ class panelPeakDifferences(wx.MiniFrame):
     def calcDipeptides(self):
         """Calculate dipeptides masses."""
         
+        # get amino acids
+        aminoacids = []
+        for abbr in mspy.monomers:
+            if mspy.monomers[abbr].category == '_InternalAA':
+                aminoacids.append(abbr)
+        
         self.dipeptides = {}
-        symbols = mspy.aminoacids.keys()
-        for x in range(len(symbols)):
-            for y in range(x, len(symbols)):
+        for x in range(len(aminoacids)):
+            for y in range(x, len(aminoacids)):
                 
-                aX = symbols[x]
-                aY = symbols[y]
+                aX = aminoacids[x]
+                aY = aminoacids[y]
                 
-                massX = mspy.aminoacids[aX].mass
-                massY = mspy.aminoacids[aY].mass
+                massX = mspy.monomers[aX].mass
+                massY = mspy.monomers[aY].mass
                 mass = (massX[0] + massY[0], massX[1] + massY[1])
                 
                 if aX != aY:
