@@ -424,6 +424,11 @@ class panelPeaklist(wx.Panel):
     def onDelete(self, evt):
         """Minus button pressed."""
         
+        # check document
+        if self.currentDocument == None:
+            wx.Bell()
+            return
+        
         # popup menu
         menuDeleteSelectedID = wx.NewId()
         menuDeleteByThresholdID = wx.NewId()
@@ -547,7 +552,7 @@ class panelPeaklist(wx.Panel):
             elif thresholdType == 'Relative Intensity':
                 threshold /= 100
                 for i, peak in enumerate(self.currentDocument.spectrum.peaklist):
-                    if peak.relIntensity < threshold:
+                    if peak.ri < threshold:
                         indexes.append(i)
             
             # use s/n
@@ -676,7 +681,7 @@ class panelPeaklist(wx.Panel):
                 elif column == 'int':
                     row.append(peak.intensity)
                 elif column == 'rel':
-                    row.append(peak.relIntensity*100)
+                    row.append(peak.ri*100)
                 elif column == 'sn':
                     row.append(peak.sn)
                 elif column == 'z':
@@ -911,7 +916,7 @@ class panelPeaklist(wx.Panel):
                 if 'int' in config.export['peaklistColumns']:
                     line += str(peak.intensity) + '\t'
                 if 'rel' in config.export['peaklistColumns']:
-                    line += str(peak.relIntensity*100) + '\t'
+                    line += str(peak.ri*100) + '\t'
                 if 'sn' in config.export['peaklistColumns']:
                     line += str(peak.sn) + '\t'
                 if 'z' in config.export['peaklistColumns']:
@@ -1032,6 +1037,7 @@ class dlgThreshold(wx.Dialog):
     
     
 
+
 class dlgCopy(wx.Dialog):
     """Set coumns to copy."""
     
@@ -1151,6 +1157,7 @@ class dlgCopy(wx.Dialog):
             config.export['peaklistColumns'].append('group')
     # ----
     
+    
 
 
 class fileDropTarget(wx.FileDropTarget):
