@@ -184,18 +184,17 @@ class panelProcessing(wx.MiniFrame):
         self.updateAvailableDocuments()
         
         mathOperation_label = wx.StaticText(panel, -1, "Operation:")
-        self.mathOperationAdd_radio = wx.RadioButton(panel, -1, "A + B   ", style=wx.RB_GROUP)
+        self.mathOperationNorm_radio = wx.RadioButton(panel, -1, "Normalize", style=wx.RB_GROUP)
+        self.mathOperationAdd_radio = wx.RadioButton(panel, -1, "A + B   ")
         self.mathOperationSub_radio = wx.RadioButton(panel, -1, "A - B   ")
-        self.mathOperationMul_radio = wx.RadioButton(panel, -1, "A * X")
-        self.mathOperationNorm_radio = wx.RadioButton(panel, -1, "Normalize")
-        self.mathOperationAdd_radio.SetValue(True)
+        self.mathOperationMul_radio = wx.RadioButton(panel, -1, "A x")
+        self.mathOperationNorm_radio.SetValue(True)
         
+        self.mathOperationNorm_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         self.mathOperationAdd_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         self.mathOperationSub_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         self.mathOperationMul_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
-        self.mathOperationNorm_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         
-        mathMul_label = wx.StaticText(panel, -1, "Multiplier X:")
         self.mathMul_value = wx.TextCtrl(panel, -1, '1', size=(70, -1), validator=mwx.validator('floatPos'))
         self.mathMul_value.Bind(wx.EVT_TEXT, self.onMathChanged)
         self.mathMul_value.Disable()
@@ -203,14 +202,13 @@ class panelProcessing(wx.MiniFrame):
         # pack elements
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         grid.Add(mathOperation_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathOperationAdd_radio, (0,1))
-        grid.Add(self.mathOperationSub_radio, (1,1))
-        grid.Add(self.mathOperationMul_radio, (2,1))
-        grid.Add(self.mathOperationNorm_radio, (3,1))
+        grid.Add(self.mathOperationNorm_radio, (0,1), (1,2))
+        grid.Add(self.mathOperationAdd_radio, (1,1), (1,2))
+        grid.Add(self.mathOperationSub_radio, (2,1), (1,2))
+        grid.Add(self.mathOperationMul_radio, (3,1))
+        grid.Add(self.mathMul_value, (3,2), flag=wx.ALIGN_LEFT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(mathSpectrumB_label, (4,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathSpectrumB_combo, (4,1), (1,3))
-        grid.Add(mathMul_label, (5,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathMul_value, (5,1), (1,3))
+        grid.Add(self.mathSpectrumB_combo, (4,1), (1,2))
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -298,10 +296,12 @@ class panelProcessing(wx.MiniFrame):
         
         # make elements
         smoothingMethod_label = wx.StaticText(panel, -1, "Method:")
-        self.smoothingMethod_combo = wx.ComboBox(panel, -1, choices=['Moving Average', 'Savitzky-Golay'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.smoothingMethod_combo = wx.ComboBox(panel, -1, choices=['Moving Average', 'Gaussian', 'Savitzky-Golay'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
         self.smoothingMethod_combo.Select(0)
-        if config.processing['smoothing']['method']=='SG':
+        if config.processing['smoothing']['method']=='GA':
             self.smoothingMethod_combo.Select(1)
+        elif config.processing['smoothing']['method']=='SG':
+            self.smoothingMethod_combo.Select(2)
         self.smoothingMethod_combo.Bind(wx.EVT_COMBOBOX, self.onSmoothingChanged)
         
         smoothingWindow_label = wx.StaticText(panel, -1, "Window size:")
@@ -441,9 +441,9 @@ class panelProcessing(wx.MiniFrame):
         self.deisotopingRemoveUnknown_check.SetValue(bool(config.processing['deisotoping']['removeUnknown']))
         
         deisotopingLabelEnvelopeTool_label = wx.StaticText(panel, -1, "Label envelope tool:")
-        self.deisotopingLabelEnvelopeTool_combo = wx.ComboBox(panel, -1, choices=['Monoisotopic Mass', 'Envelope Centroid', 'All Isotopes'], size=(160, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.deisotopingLabelEnvelopeTool_combo = wx.ComboBox(panel, -1, choices=['1st Selected', 'Monoisotopic Mass', 'Envelope Centroid', 'All Isotopes'], size=(160, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
         self.deisotopingLabelEnvelopeTool_combo.Select(1)
-        choices=['monoisotopic', 'centroid', 'isotopes']
+        choices=['1st', 'monoisotope', 'centroid', 'isotopes']
         if config.processing['deisotoping']['labelEnvelope'] in choices:
             self.deisotopingLabelEnvelopeTool_combo.Select(choices.index(config.processing['deisotoping']['labelEnvelope']))
         self.deisotopingLabelEnvelopeTool_combo.Bind(wx.EVT_COMBOBOX, self.getParams)
@@ -764,10 +764,12 @@ class panelProcessing(wx.MiniFrame):
         self.baselineOffset_slider.SetValue(presets['baseline']['offset']*100)
         
         # set smoothing
-        if presets['smoothing']['method']=='MA':
+        if presets['smoothing']['method'] == 'MA':
             self.smoothingMethod_combo.Select(0)
-        else:
+        elif presets['smoothing']['method'] == 'GA':
             self.smoothingMethod_combo.Select(1)
+        else:
+            self.smoothingMethod_combo.Select(2)
         
         self.smoothingWindow_value.SetValue(str(presets['smoothing']['windowSize']))
         self.smoothingCycles_slider.SetValue(presets['smoothing']['cycles'])
@@ -791,7 +793,7 @@ class panelProcessing(wx.MiniFrame):
         self.deisotopingRemoveUnknown_check.SetValue(bool(presets['deisotoping']['removeUnknown']))
         self.deisotopingSetAsMonoisotopic_check.SetValue(bool(presets['deisotoping']['setAsMonoisotopic']))
         
-        choices=['monoisotopic', 'centroid', 'isotopes']
+        choices=['1st', 'monoisotope', 'centroid', 'isotopes']
         if presets['deisotoping']['labelEnvelope'] in choices:
             self.deisotopingLabelEnvelopeTool_combo.Select(choices.index(presets['deisotoping']['labelEnvelope']))
         else:
@@ -849,7 +851,10 @@ class panelProcessing(wx.MiniFrame):
             return
         
         # disable / enable items
-        if self.mathOperationAdd_radio.GetValue():
+        if self.mathOperationNorm_radio.GetValue():
+            self.mathSpectrumB_combo.Disable()
+            self.mathMul_value.Disable()
+        elif self.mathOperationAdd_radio.GetValue():
             self.mathSpectrumB_combo.Enable()
             self.mathMul_value.Disable()
         elif self.mathOperationSub_radio.GetValue():
@@ -858,9 +863,6 @@ class panelProcessing(wx.MiniFrame):
         elif self.mathOperationMul_radio.GetValue():
             self.mathSpectrumB_combo.Disable()
             self.mathMul_value.Enable()
-        elif self.mathOperationNorm_radio.GetValue():
-            self.mathSpectrumB_combo.Disable()
-            self.mathMul_value.Disable()
     # ----
     
     
@@ -880,10 +882,10 @@ class panelProcessing(wx.MiniFrame):
             return
         
         # get baseline
-        baseline = self.currentDocument.spectrum.baseline(\
-            window=(1./config.processing['baseline']['precision']), \
-            smooth=True, \
-            offset=config.processing['baseline']['offset'] \
+        baseline = self.currentDocument.spectrum.baseline(
+            window = (1./config.processing['baseline']['precision']),
+            smooth = True,
+            offset = config.processing['baseline']['offset']
             )
         
         # make tmp spectrum
@@ -1079,7 +1081,9 @@ class panelProcessing(wx.MiniFrame):
         try:
             
             # math operations
-            if self.mathOperationAdd_radio.GetValue():
+            if self.mathOperationNorm_radio.GetValue():
+                config.processing['math']['operation'] = 'norm'
+            elif self.mathOperationAdd_radio.GetValue():
                 config.processing['math']['operation'] = 'add'
                 config.processing['math']['spectrumB'] = self.mathSpectrumB_combo.GetValue()
             elif self.mathOperationSub_radio.GetValue():
@@ -1088,8 +1092,6 @@ class panelProcessing(wx.MiniFrame):
             elif self.mathOperationMul_radio.GetValue():
                 config.processing['math']['operation'] = 'mul'
                 config.processing['math']['multiplier'] = float(self.mathMul_value.GetValue())
-            elif self.mathOperationNorm_radio.GetValue():
-                config.processing['math']['operation'] = 'norm'
             
             # crop
             config.processing['crop']['lowMass'] = float(self.cropLowMass_value.GetValue())
@@ -1104,7 +1106,9 @@ class panelProcessing(wx.MiniFrame):
             config.processing['smoothing']['cycles'] = int(self.smoothingCycles_slider.GetValue())
             
             config.processing['smoothing']['method'] = 'MA'
-            if self.smoothingMethod_combo.GetValue() == 'Savitzky-Golay':
+            if self.smoothingMethod_combo.GetValue() == 'Gaussian':
+                config.processing['smoothing']['method'] = 'GA'
+            elif self.smoothingMethod_combo.GetValue() == 'Savitzky-Golay':
                 config.processing['smoothing']['method'] = 'SG'
             
             # peak picking
@@ -1127,8 +1131,10 @@ class panelProcessing(wx.MiniFrame):
             config.processing['deisotoping']['setAsMonoisotopic'] = bool(self.deisotopingSetAsMonoisotopic_check.GetValue())
             
             labelEnvelope = self.deisotopingLabelEnvelopeTool_combo.GetValue()
-            if labelEnvelope == 'Monoisotopic Mass':
-                config.processing['deisotoping']['labelEnvelope'] = 'monoisotopic'
+            if labelEnvelope == '1st Selected':
+                config.processing['deisotoping']['labelEnvelope'] = '1st'
+            elif labelEnvelope == 'Monoisotopic Mass':
+                config.processing['deisotoping']['labelEnvelope'] = 'monoisotope'
             elif labelEnvelope == 'Envelope Centroid':
                 config.processing['deisotoping']['labelEnvelope'] = 'centroid'
             elif labelEnvelope == 'All Isotopes':
@@ -1193,11 +1199,11 @@ class panelProcessing(wx.MiniFrame):
         try:
             
             # correct baseline
-            self.previewData = mspy.correctBaseline(\
-                points=self.currentDocument.spectrum.points, \
-                window=(1./config.processing['baseline']['precision']), \
-                smooth=True, \
-                offset=config.processing['baseline']['offset'] \
+            self.previewData = mspy.correctBaseline(
+                points = self.currentDocument.spectrum.points,
+                window = (1./config.processing['baseline']['precision']),
+                smooth = True,
+                offset = config.processing['baseline']['offset']
             )
             
         # task canceled
@@ -1214,20 +1220,29 @@ class panelProcessing(wx.MiniFrame):
             
             # smooth data by MA
             if config.processing['smoothing']['method']=='MA':
+                
+                self.previewData = mspy.smoothMA(
+                    points = self.currentDocument.spectrum.points,
+                    window = config.processing['smoothing']['windowSize'],
+                    cycles = config.processing['smoothing']['cycles']
+                )
             
-                self.previewData = mspy.smoothMA(\
-                    points=self.currentDocument.spectrum.points, \
-                    window=config.processing['smoothing']['windowSize'], \
-                    cycles=config.processing['smoothing']['cycles']\
+            # smooth data by GA
+            elif config.processing['smoothing']['method']=='GA':
+                
+                self.previewData = mspy.smoothGA(
+                    points = self.currentDocument.spectrum.points,
+                    window = config.processing['smoothing']['windowSize'],
+                    cycles = config.processing['smoothing']['cycles']
                 )
             
             # smooth data by SG
             elif config.processing['smoothing']['method']=='SG':
-            
-                self.previewData = mspy.smoothSG(\
-                    points=self.currentDocument.spectrum.points, \
-                    window=config.processing['smoothing']['windowSize'], \
-                    cycles=config.processing['smoothing']['cycles']\
+                
+                self.previewData = mspy.smoothSG(
+                    points = self.currentDocument.spectrum.points,
+                    window = config.processing['smoothing']['windowSize'],
+                    cycles = config.processing['smoothing']['cycles']
                 )
             
         # task canceled
@@ -1256,7 +1271,10 @@ class panelProcessing(wx.MiniFrame):
                     return
             
             # process spectrum
-            if config.processing['math']['operation'] == 'add':
+            if config.processing['math']['operation'] == 'norm':
+                self.currentDocument.spectrum.normalize()
+            
+            elif config.processing['math']['operation'] == 'add':
                 self.currentDocument.spectrum.concatenate(spectrumB)
             
             elif config.processing['math']['operation'] == 'sub':
@@ -1265,9 +1283,6 @@ class panelProcessing(wx.MiniFrame):
             elif config.processing['math']['operation'] == 'mul':
                 self.currentDocument.spectrum.multiply(config.processing['math']['multiplier'])
             
-            elif config.processing['math']['operation'] == 'norm':
-                self.currentDocument.spectrum.normalize()
-            
             # remove notations
             del self.currentDocument.annotations[:]
             for sequence in self.currentDocument.sequences:
@@ -1326,10 +1341,10 @@ class panelProcessing(wx.MiniFrame):
             self.currentDocument.backup(('spectrum', 'notations'))
             
             # correct baseline
-            self.currentDocument.spectrum.correctBaseline(\
-                window=(1./config.processing['baseline']['precision']), \
-                smooth=True, \
-                offset=config.processing['baseline']['offset'] \
+            self.currentDocument.spectrum.correctBaseline(
+                window = (1./config.processing['baseline']['precision']),
+                smooth = True,
+                offset = config.processing['baseline']['offset']
             )
             
             # remove notations
@@ -1353,10 +1368,10 @@ class panelProcessing(wx.MiniFrame):
             self.currentDocument.backup(('spectrum', 'notations'))
             
             # smooth spectrum
-            self.currentDocument.spectrum.smooth(\
-                method=config.processing['smoothing']['method'], \
-                window=config.processing['smoothing']['windowSize'], \
-                cycles=config.processing['smoothing']['cycles'] \
+            self.currentDocument.spectrum.smooth(
+                method = config.processing['smoothing']['method'],
+                window = config.processing['smoothing']['windowSize'],
+                cycles = config.processing['smoothing']['cycles']
             )
             
             # remove notations
@@ -1390,18 +1405,18 @@ class panelProcessing(wx.MiniFrame):
                 smoothMethod = config.processing['smoothing']['method']
             
             # label spectrum
-            self.currentDocument.spectrum.labelScan(\
-                pickingHeight=config.processing['peakpicking']['pickingHeight'], \
-                absThreshold=config.processing['peakpicking']['absIntThreshold'], \
-                relThreshold=config.processing['peakpicking']['relIntThreshold'], \
-                snThreshold=config.processing['peakpicking']['snThreshold'], \
-                baselineWindow=baselineWindow, \
-                baselineSmooth=True, \
-                baselineOffset=config.processing['baseline']['offset'], \
-                smoothMethod=smoothMethod, \
-                smoothWindow=config.processing['smoothing']['windowSize'], \
-                smoothCycles=config.processing['smoothing']['cycles'] \
-                )
+            self.currentDocument.spectrum.labelScan(
+                pickingHeight = config.processing['peakpicking']['pickingHeight'],
+                absThreshold = config.processing['peakpicking']['absIntThreshold'],
+                relThreshold = config.processing['peakpicking']['relIntThreshold'],
+                snThreshold = config.processing['peakpicking']['snThreshold'],
+                baselineWindow = baselineWindow,
+                baselineSmooth = True,
+                baselineOffset = config.processing['baseline']['offset'],
+                smoothMethod = smoothMethod,
+                smoothWindow = config.processing['smoothing']['windowSize'],
+                smoothCycles = config.processing['smoothing']['cycles']
+            )
             
             # remove shoulder peaks
             if config.processing['peakpicking']['removeShoulders']:
@@ -1409,11 +1424,11 @@ class panelProcessing(wx.MiniFrame):
             
             # find isotopes and calculate charges
             if config.processing['peakpicking']['deisotoping']:
-                self.currentDocument.spectrum.findIsotopes(\
-                    maxCharge=config.processing['deisotoping']['maxCharge'], \
-                    mzTolerance=config.processing['deisotoping']['massTolerance'], \
-                    intTolerance=config.processing['deisotoping']['intTolerance'], \
-                    isotopeShift=config.processing['deisotoping']['isotopeShift'] \
+                self.currentDocument.spectrum.findIsotopes(
+                    maxCharge = config.processing['deisotoping']['maxCharge'],
+                    mzTolerance = config.processing['deisotoping']['massTolerance'],
+                    intTolerance = config.processing['deisotoping']['intTolerance'],
+                    isotopeShift = config.processing['deisotoping']['isotopeShift']
                 )
                 
                 # remove isotopes
@@ -1445,11 +1460,11 @@ class panelProcessing(wx.MiniFrame):
             self.currentDocument.backup(('spectrum', 'notations'))
             
             # find isotopes and calculate charges
-            self.currentDocument.spectrum.findIsotopes(\
-                maxCharge=config.processing['deisotoping']['maxCharge'], \
-                mzTolerance=config.processing['deisotoping']['massTolerance'], \
-                intTolerance=config.processing['deisotoping']['intTolerance'], \
-                isotopeShift=config.processing['deisotoping']['isotopeShift'] \
+            self.currentDocument.spectrum.findIsotopes(
+                maxCharge = config.processing['deisotoping']['maxCharge'],
+                mzTolerance = config.processing['deisotoping']['massTolerance'],
+                intTolerance = config.processing['deisotoping']['intTolerance'],
+                isotopeShift = config.processing['deisotoping']['isotopeShift']
             )
             
             # remove isotopes
@@ -1491,14 +1506,13 @@ class panelProcessing(wx.MiniFrame):
                 del sequence.matches[:]
             
             # deconvolute peaklist
-            massType = ['mo', 'av']
-            docData.spectrum.deconvolute(massType=massType[config.processing['deconvolution']['massType']])
+            docData.spectrum.deconvolute(massType=config.processing['deconvolution']['massType'])
             
             # group peaks
             if config.processing['deconvolution']['groupPeaks']:
                 docData.spectrum.groupPeaks(
-                    window=config.processing['deconvolution']['groupWindow'], \
-                    forceWindow=config.processing['deconvolution']['forceGroupWindow']
+                    window = config.processing['deconvolution']['groupWindow'],
+                    forceWindow = config.processing['deconvolution']['forceGroupWindow']
                 )
             
             # append new document
@@ -1561,11 +1575,11 @@ class panelProcessing(wx.MiniFrame):
             window = 1./config.processing['baseline']['precision']
         
         # get curent baseline
-        baseline = self.currentDocument.spectrum.baseline(\
-            window=window, \
-            smooth=True, \
-            offset=config.processing['baseline']['offset'] \
-            )
+        baseline = self.currentDocument.spectrum.baseline(
+            window = window,
+            smooth = True,
+            offset = config.processing['baseline']['offset']
+        )
         
         # get basepeak (approx. only)
         index = self.currentDocument.spectrum.points.argmax(axis=0)[1]
