@@ -377,13 +377,7 @@ class panelProfound(wx.MiniFrame):
             self.query_butt.SetBitmapLabel(images.lib['profoundQueryOn'])
         
         # fit layout
-        self.Layout()
-        self.mainSizer.Fit(self)
-        
-        # force resize
-        size = self.GetSize()
-        self.SetSize((size[0], size[1]+1))
-        self.SetSize(size)
+        mwx.layout(self, self.mainSizer)
     # ----
     
     
