@@ -110,6 +110,8 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
         self.spectrumCanvas.setProperties(distanceDigits=config.main['mzDigits'])
+        self.spectrumCanvas.setProperties(checkLimits=True)
+        self.spectrumCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.spectrumCanvas.setProperties(reverseDrawing=True)
         
         axisFont = wx.Font(config.spectrum['axisFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
@@ -133,10 +135,6 @@ class panelSpectrum(wx.Panel):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrBottombar'], size=(-1, mwx.BOTTOMBAR_HEIGHT))
         
         # make canvas toolset
-        self.canvasParameters_butt = wx.BitmapButton(panel, ID_viewCanvasProperties, images.lib['spectrumParams'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
-        self.canvasParameters_butt.SetToolTip(wx.ToolTip("Canvas properties..."))
-        self.canvasParameters_butt.Bind(wx.EVT_BUTTON, self.onCanvasProperties)
-        
         image = (images.lib['spectrumLabelsOff'], images.lib['spectrumLabelsOn'])[config.spectrum['showLabels']]
         self.showLabels_butt = wx.BitmapButton(panel, ID_viewLabels, image, size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
         self.showLabels_butt.SetToolTip(wx.ToolTip("Show / hide labels"))
@@ -214,8 +212,7 @@ class panelSpectrum(wx.Panel):
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.BOTTOMBAR_LSPACE)
-        sizer.Add(self.canvasParameters_butt, 0, wx.ALIGN_CENTER_VERTICAL)
-        sizer.Add(self.showLabels_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
+        sizer.Add(self.showLabels_butt, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.Add(self.showTicks_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.showNotations_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.labelAngle_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
@@ -438,6 +435,7 @@ class panelSpectrum(wx.Panel):
         spectrum.setProperties(labelCharge=config.spectrum['labelCharge'])
         spectrum.setProperties(labelDigits=config.main['mzDigits'])
         spectrum.setProperties(labelBgr=config.spectrum['labelBgr'])
+        spectrum.setProperties(isotopeColour=None)
         
         labelFont = wx.Font(config.spectrum['labelFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
         spectrum.setProperties(labelFont=labelFont)
@@ -553,6 +551,9 @@ class panelSpectrum(wx.Panel):
         ppmFormat = '%0.' + `config.main['ppmDigits']` + 'f'
         chargeFormat = '%d'
         
+        if position and abs(position[1]) > 10000:
+            intFormat = '%.2e'
+        
         # offset dragging
         if self.currentTool == 'offset' and distance and position:
             format = 'a.i.: %s   dist: %s' % (intFormat, intFormat)
@@ -566,8 +567,11 @@ class panelSpectrum(wx.Panel):
         
         # distance measurement
         elif distance and position:
-            format = 'm/z: %s   dist: %s   ppm: %s' % (mzFormat, mzFormat, ppmFormat)
-            label += format % (position[0], distance[0], 1e6*distance[0]/position[0])
+            charge = 0
+            if distance[0]:
+                charge = int(abs(round(1/distance[0],0)))
+            format = 'm/z: %s   dist: %s   ppm: %s   z: %s' % (mzFormat, mzFormat, ppmFormat, chargeFormat)
+            label += format % (position[0], distance[0], 1e6*distance[0]/position[0], charge*polarity)
         
         # no specific fce
         elif position:
@@ -611,17 +615,18 @@ class panelSpectrum(wx.Panel):
                 flipped = self.documents[self.currentDocument].flipped
         
         # make tmp spectrum
-        obj = mspy.plot.points(points, \
-            normalized=config.spectrum['normalize'], \
-            flipped=flipped, \
-            xOffset=xOffset, \
-            yOffset=yOffset, \
-            showInGel=False, \
-            showLines=True, \
-            showPoints=False, \
-            exactFit=True, \
-            pointColour=config.spectrum['tmpSpectrumColour'], \
-            lineColour=config.spectrum['tmpSpectrumColour'] \
+        obj = mspy.plot.points(
+            points = points,
+            normalized = config.spectrum['normalize'],
+            flipped = flipped,
+            xOffset = xOffset,
+            yOffset = yOffset,
+            showInGel = False,
+            showLines = True,
+            showPoints = False,
+            exactFit = True,
+            pointColour = config.spectrum['tmpSpectrumColour'],
+            lineColour = config.spectrum['tmpSpectrumColour']
         )
         
         # set normalization
@@ -667,22 +672,23 @@ class panelSpectrum(wx.Panel):
         
         # add points to container
         labelFont = wx.Font(config.spectrum['labelFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
-        obj = mspy.plot.annotations(notations, \
-            normalized=config.spectrum['normalize'], \
-            flipped=flipped, \
-            xOffset=xOffset, \
-            yOffset=yOffset, \
-            exactFit=True, \
-            showInGel=False, \
-            showPoints=config.spectrum['notationMarks'], \
-            showLabels=config.spectrum['notationLabels'], \
-            showXPos=config.spectrum['notationMZ'], \
-            xPosDigits=config.main['mzDigits'], \
-            pointColour=config.spectrum['notationMarksColour'], \
-            labelAngle=config.spectrum['labelAngle'], \
-            labelBgr=config.spectrum['labelBgr'], \
-            labelFont=labelFont, \
-            labelMaxLength=config.spectrum['notationMaxLength'], \
+        obj = mspy.plot.annotations(
+            points = notations,
+            normalized = config.spectrum['normalize'],
+            flipped = flipped,
+            xOffset = xOffset,
+            yOffset = yOffset,
+            exactFit = True,
+            showInGel = False,
+            showPoints = config.spectrum['notationMarks'],
+            showLabels = config.spectrum['notationLabels'],
+            showXPos = config.spectrum['notationMZ'],
+            xPosDigits = config.main['mzDigits'],
+            pointColour = config.spectrum['notationMarksColour'],
+            labelAngle = config.spectrum['labelAngle'],
+            labelBgr = config.spectrum['labelBgr'],
+            labelFont = labelFont,
+            labelMaxLength = config.spectrum['notationMaxLength']
         )
         
         # set normalization
@@ -818,19 +824,19 @@ class panelSpectrum(wx.Panel):
             baselineWindow = 1./config.processing['baseline']['precision']
         
         # get baseline
-        baseline = self.documents[self.currentDocument].spectrum.baseline(\
-            window=baselineWindow, \
-            smooth=True, \
-            offset=config.processing['baseline']['offset'] \
+        baseline = self.documents[self.currentDocument].spectrum.baseline(
+            window = baselineWindow,
+            smooth = True,
+            offset = config.processing['baseline']['offset']
         )
         
         # label peak
-        peak = mspy.labelPeak(\
-            points=self.documents[self.currentDocument].spectrum.points, \
-            minX=selection[0], \
-            maxX=selection[2], \
-            pickingHeight=config.processing['peakpicking']['pickingHeight'], \
-            baselineData=baseline \
+        peak = mspy.labelPeak(
+            points = self.documents[self.currentDocument].spectrum.points,
+            minX = selection[0],
+            maxX = selection[2],
+            pickingHeight = config.processing['peakpicking']['pickingHeight'],
+            baselineData = baseline
         )
         
         if peak:
@@ -859,17 +865,17 @@ class panelSpectrum(wx.Panel):
             baselineWindow = 1./config.processing['baseline']['precision']
         
         # get baseline
-        baseline = self.documents[self.currentDocument].spectrum.baseline(\
-            window=baselineWindow, \
-            smooth=True, \
-            offset=config.processing['baseline']['offset'] \
+        baseline = self.documents[self.currentDocument].spectrum.baseline(
+            window = baselineWindow,
+            smooth = True,
+            offset = config.processing['baseline']['offset']
         )
         
         # label point
-        peak = mspy.labelPoint(\
-            points=self.documents[self.currentDocument].spectrum.points, \
-            mz=mz, \
-            baselineData=baseline \
+        peak = mspy.labelPoint(
+            points = self.documents[self.currentDocument].spectrum.points,
+            mz = mz,
+            baselineData = baseline
         )
         
         if peak:
@@ -898,21 +904,21 @@ class panelSpectrum(wx.Panel):
             baselineWindow = 1./config.processing['baseline']['precision']
         
         # get baseline
-        baseline = self.documents[self.currentDocument].spectrum.baseline(\
-            window=baselineWindow, \
-            smooth=True, \
-            offset=config.processing['baseline']['offset'] \
+        baseline = self.documents[self.currentDocument].spectrum.baseline(
+            window = baselineWindow,
+            smooth = True,
+            offset = config.processing['baseline']['offset']
         )
         
         # label isotopes
         peaks = []
         buff = []
         for isotope in isotopes:
-            peak = mspy.labelPeak(\
-                points=self.documents[self.currentDocument].spectrum.points, \
-                mz=isotope, \
-                pickingHeight=config.processing['peakpicking']['pickingHeight'], \
-                baselineData=baseline \
+            peak = mspy.labelPeak(
+                points = self.documents[self.currentDocument].spectrum.points,
+                mz = isotope,
+                pickingHeight = config.processing['peakpicking']['pickingHeight'],
+                baselineData = baseline
             )
             if peak and not peak.mz in buff:
                 peaks.append(peak)
@@ -930,17 +936,8 @@ class panelSpectrum(wx.Panel):
         if self.documents[self.currentDocument].spectrum.polarity == -1:
             polarity = -1
         
-        # label all isotopes
-        if config.processing['deisotoping']['labelEnvelope'] == 'isotopes':
-            groupname = self.documents[self.currentDocument].spectrum.peaklist.nextGroupName()
-            for x, peak in enumerate(peaks):
-                peak.setIsotope(x)
-                peak.setCharge(charge*polarity)
-                peak.setGroup(groupname)
-                self.documents[self.currentDocument].spectrum.peaklist.append(peak)
-        
-        # label monoisotopic peak
-        elif config.processing['deisotoping']['labelEnvelope'] == 'monoisotopic':
+        # label 1st isotope
+        if config.processing['deisotoping']['labelEnvelope'] == '1st':
             
             basepeak = peaks[0]
             sumIntensity = 0
@@ -963,17 +960,25 @@ class panelSpectrum(wx.Panel):
                 ai = base + sumIntensity / len(isotopes)
                 sn = (ai - base) * basepeak.sn / (basepeak.ai - basepeak.base)
             
-            peak = mspy.peak(mz=peaks[0].mz, \
-                ai=ai, \
-                base=base, \
-                sn=sn, \
-                charge=charge*polarity, \
-                isotope=0, \
-                fwhm=None \
+            peak = mspy.peak(
+                mz = peaks[0].mz,
+                ai = ai,
+                base = base,
+                sn = sn,
+                charge = charge*polarity,
+                isotope = 0,
+                fwhm = None
             )
             
             self.documents[self.currentDocument].spectrum.peaklist.append(peak)
         
+        # label monoisotopic peak
+        elif config.processing['deisotoping']['labelEnvelope'] == 'monoisotope':
+            peak = mspy.envelopeMonoisotope(peaks, charge=charge*polarity, intensity=config.processing['deisotoping']['envelopeIntensity'])
+            if peak:
+                peak.setCharge(charge*polarity)
+                self.documents[self.currentDocument].spectrum.peaklist.append(peak)
+        
         # label envelope centroid
         elif config.processing['deisotoping']['labelEnvelope'] == 'centroid':
             peak = mspy.envelopeCentroid(peaks, height=0.5, intensity=config.processing['deisotoping']['envelopeIntensity'])
@@ -981,6 +986,15 @@ class panelSpectrum(wx.Panel):
                 peak.setCharge(charge*polarity)
                 self.documents[self.currentDocument].spectrum.peaklist.append(peak)
         
+        # label all isotopes
+        if config.processing['deisotoping']['labelEnvelope'] == 'isotopes':
+            groupname = self.documents[self.currentDocument].spectrum.peaklist.nextGroupName()
+            for x, peak in enumerate(peaks):
+                peak.setIsotope(x)
+                peak.setCharge(charge*polarity)
+                peak.setGroup(groupname)
+                self.documents[self.currentDocument].spectrum.peaklist.append(peak)
+        
         # update gui
         self.parent.onDocumentChanged(('spectrum'))
     # ----
