@@ -78,9 +78,8 @@ class panelSpectrumGenerator(wx.MiniFrame):
         # fit layout
         self.mainSizer.Fit(self)
         self.SetSizer(self.mainSizer)
-        size = self.GetSize()
-        self.SetSize((size[0],size[1]+1)) # layout hack
         self.SetMinSize(self.GetSize())
+        mwx.layout(self, self.mainSizer)
     # ----
     
     
@@ -91,7 +90,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrToolbar'], size=(-1, mwx.TOOLBAR_HEIGHT))
         
         # make elements
-        fwhm_label = wx.StaticText(panel, -1, "Default FWHM:")
+        fwhm_label = wx.StaticText(panel, -1, "FWHM:")
         fwhm_label.SetFont(wx.SMALL_FONT)
         self.fwhm_value = wx.TextCtrl(panel, -1, str(config.generator['fwhm']), size=(60, -1), validator=mwx.validator('floatPos'))
         
@@ -204,6 +203,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.spectrumCanvas.setProperties(showCurXPos=True)
         self.spectrumCanvas.setProperties(showCurYPos=True)
         self.spectrumCanvas.setProperties(showCurCharge=True)
+        self.spectrumCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.spectrumCanvas.setProperties(reverseDrawing=True)
         
         self.spectrumCanvas.setLMBFunction('xDistance')
@@ -513,16 +513,17 @@ class panelSpectrumGenerator(wx.MiniFrame):
         
         # add main profile spectrum to container
         labelFont = wx.Font(config.spectrum['labelFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
-        spectrum = mspy.plot.spectrum(mspy.scan(points=profile, peaks=peaklist), \
-            spectrumColour=(16,71,185), \
-            tickColour=(255,0,0), \
-            showPoints=config.spectrum['showDataPoints'], \
-            showLabels=config.spectrum['showLabels'], \
-            showTicks=True, \
-            labelDigits=config.main['mzDigits'], \
-            labelBgr=config.spectrum['labelBgr'], \
-            labelAngle=config.spectrum['labelAngle'],
-            labelFont=labelFont
+        spectrum = mspy.plot.spectrum(
+            scan = mspy.scan(points=profile, peaks=peaklist),
+            spectrumColour = (16,71,185),
+            tickColour = (255,0,0),
+            showPoints = config.spectrum['showDataPoints'],
+            showLabels = config.spectrum['showLabels'],
+            showTicks = True,
+            labelDigits = config.main['mzDigits'],
+            labelBgr = config.spectrum['labelBgr'],
+            labelAngle = config.spectrum['labelAngle'],
+            labelFont = labelFont
         )
         self.spectrumContainer.append(spectrum)
         
@@ -530,11 +531,12 @@ class panelSpectrumGenerator(wx.MiniFrame):
         if config.generator['showPeaks']:
             if self.currentPeaks != None:
                 for peak in self.currentPeaks:
-                    spectrum = mspy.plot.points(peak, \
-                        lineColour=(50,140,0), \
-                        showLines=True, \
-                        showPoints=False, \
-                        exactFit=True
+                    spectrum = mspy.plot.points(
+                        points = peak,
+                        lineColour = (50,140,0),
+                        showLines = True,
+                        showPoints = False,
+                        exactFit = True
                     )
                     self.spectrumContainer.append(spectrum)
         
@@ -572,12 +574,12 @@ class panelSpectrumGenerator(wx.MiniFrame):
         try:
             
             # make profile spectrum
-            self.currentProfile = mspy.profile( \
-                peaklist=self.currentDocument.spectrum.peaklist, \
-                fwhm=config.generator['fwhm'], \
-                points=config.generator['points'], \
-                noise=config.generator['noise'], \
-                forceFwhm=config.generator['forceFwhm'] \
+            self.currentProfile = mspy.profile(
+                peaklist = self.currentDocument.spectrum.peaklist,
+                fwhm = config.generator['fwhm'],
+                points = config.generator['points'],
+                noise = config.generator['noise'],
+                forceFwhm = config.generator['forceFwhm']
             )
             
             # make peak spectra
@@ -590,11 +592,11 @@ class panelSpectrumGenerator(wx.MiniFrame):
                     fwhm = peak.fwhm
                 
                 # calc peak
-                points = mspy.gaussian( \
-                    mz=peak.mz, \
-                    ai=peak.ai, \
-                    base=peak.base, \
-                    fwhm=fwhm \
+                points = mspy.gaussian(
+                    mz = peak.mz,
+                    ai = peak.ai,
+                    base = peak.base,
+                    fwhm = fwhm
                 )
                 self.currentPeaks.append(points)
         
