@@ -23,7 +23,8 @@ from objects import *
 # register modules
 from utilities import *
 from processing import *
-from mascot import *
+from proteo import *
+from envfit import *
 
 # register parsers
 from parser_xy import parseXY
