@@ -37,7 +37,7 @@ class element:
         isotopes: (dict) dict of isotopes {mass number:(mass, abundance),...}
     """
     
-    def __init__(self, name='', symbol='', atomicNumber='', isotopes={}):
+    def __init__(self, name, symbol, atomicNumber, isotopes={}):
         
         self.name = name
         self.symbol = symbol
@@ -62,25 +62,31 @@ class element:
     
 
 
-class aminoacid:
-    """Amino acid object definition.
-        name: (str) name
-        symbol: (str) one-letter symbol
+class monomer:
+    """Monomer object definition.
+        abbr: (str) unique monomer abbreviation
         formula: (str) molecular formula
-        abbr: (str) three-letter abbreviation
+        losses: (list) list of applicable neutral losses
+        name: (str) name
+        category: (str) category name
     """
     
-    def __init__(self, name='', symbol='', formula='', abbr=''):
+    def __init__(self, abbr, formula, losses=[], name='', category=''):
         
-        self.name = name
-        self.symbol = symbol
-        self.formula = formula
         self.abbr = abbr
+        self.formula = formula
+        self.losses = losses
+        self.name = name
+        self.category = category
         
         # init masses and composition
         cmpd = objects.compound(self.formula)
         self.composition = cmpd.composition()
         self.mass = cmpd.mass()
+        
+        # check formulae
+        for loss in losses:
+            cmpd = objects.compound(loss)
     # ----
     
 
@@ -103,6 +109,10 @@ class enzyme:
         self.cTermFormula = cTermFormula
         self.modsBefore = modsBefore
         self.modsAfter = modsAfter
+        
+        # check formulae
+        cmpd = objects.compound(nTermFormula)
+        cmpd = objects.compound(cTermFormula)
     # ----
     
 
@@ -110,25 +120,25 @@ class enzyme:
 class fragment:
     """Peptide ion fragment object definition.
         name: (str) name
-        teminus: (N or C on S or I) fragment type (N-terminal, C-terminal, I-internal, S-single amino)
-        specifity: (str) specific amino acids for this fragment
+        teminus: (M or N or C on S or I) fragment type (M-molecular ion, N-terminal, C-terminal, I-internal, S-single amino)
         nTermFormula: (str) molecular formula of N-terminal gain or loss
         cTermFormula: (str) molecular formula of C-terminal gain or loss
-        lossFormula: (str) molecular formula of neutral loss
         nTermFilter: (bool) filter N-terminal fragment
         cTermFilter: (bool) filter C-terminal fragment
     """
     
-    def __init__(self, name='', terminus='', specifity='', nTermFormula='', cTermFormula='', lossFormula='', nTermFilter=False, cTermFilter=False):
+    def __init__(self, name='', terminus='', nTermFormula='', cTermFormula='', nTermFilter=False, cTermFilter=False):
         
         self.name = name
         self.terminus = terminus
-        self.specifity = specifity
         self.nTermFormula = nTermFormula
         self.cTermFormula = cTermFormula
-        self.lossFormula = lossFormula
         self.nTermFilter = nTermFilter
         self.cTermFilter = cTermFilter
+        
+        # check formulae
+        cmpd = objects.compound(nTermFormula)
+        cmpd = objects.compound(cTermFormula)
     # ----
     
 
@@ -282,28 +292,30 @@ elements = {
     'Zr': element( name='Zirconium', symbol='Zr', atomicNumber=40, isotopes={96: (95.908276000000001, 0.028000000000000001), 90: (89.904703699999999, 0.51449999999999996), 91: (90.905645000000007, 0.11219999999999999), 92: (91.905040099999994, 0.17150000000000001), 94: (93.906315800000002, 0.17380000000000001)}),
 }
 
-aminoacids = {
-    'A': aminoacid( name='Alanine', symbol='A', formula='C3H5NO', abbr='Ala'),
-    'C': aminoacid( name='Cysteine', symbol='C', formula='C3H5NOS', abbr='Cys'),
-    'D': aminoacid( name='Aspartic Acid', symbol='D', formula='C4H5NO3', abbr='Asp'),
-    'E': aminoacid( name='Glutamic Acid', symbol='E', formula='C5H7NO3', abbr='Glu'),
-    'F': aminoacid( name='Phenylalanine', symbol='F', formula='C9H9NO', abbr='Phe'),
-    'G': aminoacid( name='Glycine', symbol='G', formula='C2H3NO', abbr='Gly'),
-    'H': aminoacid( name='Histidine', symbol='H', formula='C6H7N3O', abbr='His'),
-    'I': aminoacid( name='Isoleucine', symbol='I', formula='C6H11NO', abbr='Ile'),
-    'K': aminoacid( name='Lysine', symbol='K', formula='C6H12N2O', abbr='Lys'),
-    'L': aminoacid( name='Leucine', symbol='L', formula='C6H11NO', abbr='Leu'),
-    'M': aminoacid( name='Methionine', symbol='M', formula='C5H9NSO', abbr='Met'),
-    'N': aminoacid( name='Asparagine', symbol='N', formula='C4H6O2N2', abbr='Asn'),
-    'O': aminoacid( name='Ornithine', symbol='O', formula='C5H10N2O', abbr='Ort'),
-    'P': aminoacid( name='Proline', symbol='P', formula='C5H7NO', abbr='Pro'),
-    'Q': aminoacid( name='Glutamine', symbol='Q', formula='C5H8N2O2', abbr='Gln'),
-    'R': aminoacid( name='Arginine', symbol='R', formula='C6H12N4O', abbr='Arg'),
-    'S': aminoacid( name='Serine', symbol='S', formula='C3H5NO2', abbr='Ser'),
-    'T': aminoacid( name='Threonine', symbol='T', formula='C4H7NO2', abbr='Thr'),
-    'V': aminoacid( name='Valine', symbol='V', formula='C5H9NO', abbr='Val'),
-    'W': aminoacid( name='Tryptophan', symbol='W', formula='C11H10N2O', abbr='Trp'),
-    'Y': aminoacid( name='Tyrosine', symbol='Y', formula='C9H9NO2', abbr='Tyr'),
+monomers = {
+    
+    # regular amino acids for protein and peptide sequences
+    'A': monomer( abbr='A', name='Alanine', formula='C3H5NO', category='_InternalAA'),
+    'C': monomer( abbr='C', name='Cysteine', formula='C3H5NOS', category='_InternalAA'),
+    'D': monomer( abbr='D', name='Aspartic Acid', formula='C4H5NO3', losses=['H2O'], category='_InternalAA'),
+    'E': monomer( abbr='E', name='Glutamic Acid', formula='C5H7NO3', losses=['H2O'], category='_InternalAA'),
+    'F': monomer( abbr='F', name='Phenylalanine', formula='C9H9NO', category='_InternalAA'),
+    'G': monomer( abbr='G', name='Glycine', formula='C2H3NO', category='_InternalAA'),
+    'H': monomer( abbr='H', name='Histidine', formula='C6H7N3O', category='_InternalAA'),
+    'I': monomer( abbr='I', name='Isoleucine', formula='C6H11NO', category='_InternalAA'),
+    'K': monomer( abbr='K', name='Lysine', formula='C6H12N2O', losses=['NH3'], category='_InternalAA'),
+    'L': monomer( abbr='L', name='Leucine', formula='C6H11NO', category='_InternalAA'),
+    'M': monomer( abbr='M', name='Methionine', formula='C5H9NSO', category='_InternalAA'),
+    'N': monomer( abbr='N', name='Asparagine', formula='C4H6O2N2', losses=['NH3'], category='_InternalAA'),
+    'O': monomer( abbr='O', name='Ornithine', formula='C5H10N2O', category='_InternalAA'),
+    'P': monomer( abbr='P', name='Proline', formula='C5H7NO', category='_InternalAA'),
+    'Q': monomer( abbr='Q', name='Glutamine', formula='C5H8N2O2', losses=['NH3'], category='_InternalAA'),
+    'R': monomer( abbr='R', name='Arginine', formula='C6H12N4O', losses=['NH3'], category='_InternalAA'),
+    'S': monomer( abbr='S', name='Serine', formula='C3H5NO2', losses=['H2O','H3PO4'], category='_InternalAA'),
+    'T': monomer( abbr='T', name='Threonine', formula='C4H7NO2', losses=['H2O','H3PO4'], category='_InternalAA'),
+    'V': monomer( abbr='V', name='Valine', formula='C5H9NO', category='_InternalAA'),
+    'W': monomer( abbr='W', name='Tryptophan', formula='C11H10N2O', category='_InternalAA'),
+    'Y': monomer( abbr='Y', name='Tyrosine', formula='C9H9NO2', losses=['H3PO4'], category='_InternalAA'),
 }
 
 enzymes = {
@@ -335,29 +347,18 @@ enzymes = {
 }
 
 fragments = {
-    'a': fragment( name='a', terminus='N', specifity='', nTermFormula='', cTermFormula='C-1O-1H-1', lossFormula='', nTermFilter=True, cTermFilter=True),
-    'a-H2O': fragment( name='a-H2O', terminus='N', specifity='STED', nTermFormula='', cTermFormula='C-1O-1H-1', lossFormula='H2O', nTermFilter=True, cTermFilter=True),
-    'a-H3PO4': fragment( name='a-H3PO4', terminus='N', specifity='STY', nTermFormula='', cTermFormula='C-1O-1H-1', lossFormula='H3PO4', nTermFilter=True, cTermFilter=True),
-    'a-NH3': fragment( name='a-NH3', terminus='N', specifity='RKQN', nTermFormula='', cTermFormula='C-1O-1H-1', lossFormula='NH3', nTermFilter=True, cTermFilter=True),
-    'b': fragment( name='b', terminus='N', specifity='', nTermFormula='', cTermFormula='H-1', lossFormula='', nTermFilter=True, cTermFilter=True),
-    'b-H2O': fragment( name='b-H2O', terminus='N', specifity='STED', nTermFormula='', cTermFormula='H-1', lossFormula='H2O', nTermFilter=True, cTermFilter=True),
-    'b-H3PO4': fragment( name='b-H3PO4', terminus='N', specifity='STY', nTermFormula='', cTermFormula='H-1', lossFormula='H3PO4', nTermFilter=True, cTermFilter=True),
-    'b-NH3': fragment( name='b-NH3', terminus='N', specifity='RKQN', nTermFormula='', cTermFormula='H-1', lossFormula='NH3', nTermFilter=True, cTermFilter=True),
-    'c': fragment( name='c', terminus='N', specifity='', nTermFormula='', cTermFormula='NH2', lossFormula='', nTermFilter=True, cTermFilter=True),
-    'c-ladder': fragment( name='c-ladder', terminus='N', specifity='', nTermFormula='', cTermFormula='OH', lossFormula='', nTermFilter=False, cTermFilter=True),
-    'im': fragment( name='im', terminus='S', specifity='', nTermFormula='H', cTermFormula='C-1O-1H-1', lossFormula='', nTermFilter=True, cTermFilter=False),
-    'int': fragment( name='int', terminus='I', specifity='', nTermFormula='H', cTermFormula='H-1', lossFormula='', nTermFilter=False, cTermFilter=False),
-    'int-CO': fragment( name='int-CO', terminus='I', specifity='', nTermFormula='H', cTermFormula='C-1O-1H-1', lossFormula='', nTermFilter=False, cTermFilter=False),
-    'int-H2O': fragment( name='int-H2O', terminus='I', specifity='STED', nTermFormula='H', cTermFormula='H-1', lossFormula='H2O', nTermFilter=False, cTermFilter=False),
-    'int-H3PO4': fragment( name='int-H3PO4', terminus='C', specifity='STY', nTermFormula='H', cTermFormula='H-1', lossFormula='H3PO4', nTermFilter=False, cTermFilter=False),
-    'int-NH3': fragment( name='int-NH3', terminus='I', specifity='RKQN', nTermFormula='H', cTermFormula='H-1', lossFormula='NH3', nTermFilter=False, cTermFilter=False),
-    'n-ladder': fragment( name='n-ladder', terminus='C', specifity='', nTermFormula='H', cTermFormula='', lossFormula='', nTermFilter=True, cTermFilter=False),
-    'x': fragment( name='x', terminus='C', specifity='', nTermFormula='COH-1', cTermFormula='', lossFormula='', nTermFilter=False, cTermFilter=True),
-    'y': fragment( name='y', terminus='C', specifity='', nTermFormula='H', cTermFormula='', lossFormula='', nTermFilter=True, cTermFilter=False),
-    'y-H2O': fragment( name='y-H2O', terminus='C', specifity='STED', nTermFormula='H', cTermFormula='', lossFormula='H2O', nTermFilter=True, cTermFilter=False),
-    'y-H3PO4': fragment( name='y-H3PO4', terminus='C', specifity='STY', nTermFormula='H', cTermFormula='', lossFormula='H3PO4', nTermFilter=True, cTermFilter=False),
-    'y-NH3': fragment( name='y-NH3', terminus='C', specifity='RKQN', nTermFormula='H', cTermFormula='', lossFormula='NH3', nTermFilter=True, cTermFilter=False),
-    'z': fragment( name='z', terminus='C', specifity='', nTermFormula='N-1H-1', cTermFormula='', lossFormula='', nTermFilter=True, cTermFilter=False),
+    'M': fragment( name='M', terminus='M', nTermFilter=False, cTermFilter=False),
+    'im': fragment( name='im', terminus='S', nTermFormula='H', cTermFormula='C-1O-1H-1', nTermFilter=False, cTermFilter=False),
+    'a': fragment( name='a', terminus='N', cTermFormula='C-1O-1H-1', nTermFilter=True, cTermFilter=True),
+    'b': fragment( name='b', terminus='N', cTermFormula='H-1', nTermFilter=True, cTermFilter=True),
+    'c': fragment( name='c', terminus='N', cTermFormula='NH2', nTermFilter=False, cTermFilter=True),
+    'x': fragment( name='x', terminus='C', nTermFormula='COH-1', nTermFilter=True, cTermFilter=False),
+    'y': fragment( name='y', terminus='C', nTermFormula='H', nTermFilter=True, cTermFilter=False),
+    'z': fragment( name='z', terminus='C', nTermFormula='N-1H-2', nTermFilter=True, cTermFilter=False),
+    'c-ladder': fragment( name='c-ladder', terminus='N', cTermFormula='OH', nTermFilter=True, cTermFilter=True),
+    'n-ladder': fragment( name='n-ladder', terminus='C', nTermFormula='H', nTermFilter=True, cTermFilter=False),
+    'int-b': fragment( name='int-b', terminus='I', nTermFormula='H', cTermFormula='H-1'),
+    'int-a': fragment( name='int-a', terminus='I', nTermFormula='H', cTermFormula='C-1O-1H-1'),
 }
 
 modifications = {
@@ -422,89 +423,49 @@ modifications = {
 # LOAD FUNCTIONS
 # --------------
 
-def loadElements(path=os.path.join(blocksdir, 'elements.xml'), clear=False):
-    """Parse elements XML and get data."""
+def loadMonomers(path=os.path.join(blocksdir, 'monomers.xml'), clear=False, replace=False):
+    """Parse monomers XML and get data."""
     
     container = {}
     
     # parse XML
     document = xml.dom.minidom.parse(path)
     
-    # get elements
-    elementTags = document.getElementsByTagName('element')
-    for x, elementTag in enumerate(elementTags):
-        
-        # get symbol, name and atomic number
-        name = elementTag.getAttribute('name')
-        symbol = str(elementTag.getAttribute('symbol'))
-        atomicNumber = elementTag.getAttribute('atomicNumber')
-        
-        # get masses
-        massTags = elementTag.getElementsByTagName('mass')
-        massMo = float(massTags[0].getAttribute('monoisotopic'))
-        massAv = float(massTags[0].getAttribute('average'))
-        mass = (massMo, massAv)
-        
-        # get isotopes
-        isotopes = {}
-        isotopeTags = elementTag.getElementsByTagName('isotope')
-        for isotopeTag in isotopeTags:
-            massNumber = int(isotopeTag.getAttribute('massNumber'))
-            imass = float(isotopeTag.getAttribute('mass'))
-            abundance = float(isotopeTag.getAttribute('abundance'))
-            isotopes[massNumber] = (imass,abundance)
-        
-        # add object
-        container[symbol] = element( \
-            name=name, \
-            symbol=symbol, \
-            atomicNumber=atomicNumber, \
-            isotopes=isotopes \
-        )
-    
-    # update current lib
-    if clear:
-        elements.clear()
-    for key in container:
-        elements[key] = container[key]
-# ----
-
-
-def loadAminoacids(path=os.path.join(blocksdir, 'aminoacids.xml'), clear=False):
-    """Parse amino acid XML and get data."""
-    
-    container = {}
-    
-    # parse XML
-    document = xml.dom.minidom.parse(path)
-    
-    # get aminoacids
-    aminoacidTags = document.getElementsByTagName('aminoacid')
-    for x, aminoacidTag in enumerate(aminoacidTags):
+    # get monomers
+    monomerTags = document.getElementsByTagName('monomer')
+    for x, monomerTag in enumerate(monomerTags):
         
         # get basic data
-        name = aminoacidTag.getAttribute('name')
-        symbol = aminoacidTag.getAttribute('symbol')
-        abbr = aminoacidTag.getAttribute('abbr')
-        formula = aminoacidTag.getAttribute('formula')
+        abbr = monomerTag.getAttribute('abbr')
+        name = monomerTag.getAttribute('name')
+        category = monomerTag.getAttribute('category')
+        formula = monomerTag.getAttribute('formula')
+        
+        # get losses
+        losses = []
+        attr = monomerTag.getAttribute('losses')
+        if attr:
+            losses = attr.split(';')
         
         # add object
-        container[symbol] = aminoacid( \
-            name=name, \
-            symbol=symbol, \
-            formula=formula, \
-            abbr=abbr \
+        container[abbr] = monomer(
+            abbr = abbr,
+            formula = formula,
+            losses = losses,
+            name = name,
+            category = category
         )
     
     # update current lib
-    if clear:
-        aminoacids.clear()
+    if container and clear:
+        monomers.clear()
     for key in container:
-        aminoacids[key] = container[key]
+        if replace or not key in monomers:
+            monomers[key] = container[key]
 # ----
 
 
-def loadEnzymes(path=os.path.join(blocksdir, 'enzymes.xml'), clear=False):
+def loadEnzymes(path=os.path.join(blocksdir, 'enzymes.xml'), clear=False, replace=True):
     """Parse enzymes XML and get data."""
     
     container = {}
@@ -534,72 +495,25 @@ def loadEnzymes(path=os.path.join(blocksdir, 'enzymes.xml'), clear=False):
         modsAfter = bool(int(allowModsTags[0].getAttribute('after')))
         
         # add objects
-        container[name] = enzyme( \
-            name=name, \
-            expression=expression, \
-            nTermFormula=nTermFormula, \
-            cTermFormula=cTermFormula, \
-            modsBefore=modsBefore, \
-            modsAfter=modsAfter \
+        container[name] = enzyme(
+            name = name,
+            expression = expression,
+            nTermFormula = nTermFormula,
+            cTermFormula = cTermFormula,
+            modsBefore = modsBefore,
+            modsAfter = modsAfter
         )
     
     # update current lib
-    if clear:
+    if container and clear:
         enzymes.clear()
     for key in container:
-        enzymes[key] = container[key]
+        if replace or not key in enzymes:
+            enzymes[key] = container[key]
 # ----
 
 
-def loadFragments(path=os.path.join(blocksdir, 'fragments.xml'), clear=False):
-    """Parse fragments XML and get data."""
-    
-    container = {}
-    
-    # parse XML
-    document = xml.dom.minidom.parse(path)
-    
-    # get fragments
-    fragmentTags = document.getElementsByTagName('fragment')
-    for x, fragmentTag in enumerate(fragmentTags):
-        
-        # get basic data
-        name = fragmentTag.getAttribute('name')
-        terminus = fragmentTag.getAttribute('terminus')
-        specifity = fragmentTag.getAttribute('specifity')
-        
-        # get formula
-        formulaTags = fragmentTag.getElementsByTagName('formula')
-        cTermFormula = str(formulaTags[0].getAttribute('cTerm'))
-        nTermFormula = str(formulaTags[0].getAttribute('nTerm'))
-        lossFormula = str(formulaTags[0].getAttribute('neutralLoss'))
-        
-        # get filter
-        termFilterTags = fragmentTag.getElementsByTagName('termFilter')
-        nTermFilter = bool(int(termFilterTags[0].getAttribute('nTerm')))
-        cTermFilter = bool(int(termFilterTags[0].getAttribute('cTerm')))
-        
-        # add object
-        container[name] = fragment(
-            name=name, \
-            terminus=terminus, \
-            specifity=specifity, \
-            cTermFormula=cTermFormula, \
-            nTermFormula=nTermFormula, \
-            lossFormula=lossFormula, \
-            nTermFilter=nTermFilter, \
-            cTermFilter=cTermFilter \
-        )
-    
-    # update current lib
-    if clear:
-        fragments.clear()
-    for key in container:
-        fragments[key] = container[key]
-# ----
-
-
-def loadModifications(path=os.path.join(blocksdir, 'modifications.xml'), clear=False):
+def loadModifications(path=os.path.join(blocksdir, 'modifications.xml'), clear=False, replace=True):
     """Parse modifications XML and get data."""
     
     container = {}
@@ -629,20 +543,21 @@ def loadModifications(path=os.path.join(blocksdir, 'modifications.xml'), clear=F
         description = _getNodeText(descriptionTags[0])
         
         # add object
-        container[name] = modification( \
-            name=name, \
-            gainFormula=gainFormula, \
-            lossFormula=lossFormula, \
-            aminoSpecifity=aminoSpecifity, \
-            termSpecifity=termSpecifity, \
-            description=description \
+        container[name] = modification(
+            name = name,
+            gainFormula = gainFormula,
+            lossFormula = lossFormula,
+            aminoSpecifity = aminoSpecifity,
+            termSpecifity = termSpecifity,
+            description = description
         )
     
     # update current lib
-    if clear:
+    if container and clear:
         modifications.clear()
     for key in container:
-        modifications[key] = container[key]
+        if replace or not key in modifications:
+            modifications[key] = container[key]
 # ----
 
 
@@ -662,56 +577,22 @@ def _getNodeText(node):
 # SAVE FUNCTIONS
 # --------------
 
-def saveElements(path=os.path.join(blocksdir, 'elements.xml')):
-    """Make and save elements XML."""
+def saveMonomers(path=os.path.join(blocksdir, 'monomers.xml')):
+    """Make and save monomers XML."""
     
-    # make elements xml
+    # make monomers xml
     buff = '<?xml version="1.0" encoding="utf-8" ?>\n'
-    buff += '<mspyElements version="1.0">\n'
+    buff += '<mspyMonomers version="1.0">\n'
     
-    symbols = elements.keys()
-    symbols.sort()
-    for symbol in symbols:
-        buff += '  <element symbol="%s" name="%s" atomicNumber="%s">\n' % (elements[symbol].symbol, elements[symbol].name, elements[symbol].atomicNumber)
-        buff += '    <mass monoisotopic="%s" average="%s" />\n' % elements[symbol].mass
-        buff += '    <isotopes>\n'
+    abbrs = monomers.keys()
+    abbrs.sort()
+    for abbr in abbrs:
+        if monomers[abbr].category != '_InternalAA':
+            buff += '  <monomer abbr="%s" name="%s" formula="%s" category="%s" losses="%s" />\n' % (monomers[abbr].abbr, monomers[abbr].name, monomers[abbr].formula, monomers[abbr].category, ';'.join(monomers[abbr].losses))
         
-        isotopes = elements[symbol].isotopes.keys()
-        isotopes.sort()
-        for isotope in isotopes:
-            buff += '      <isotope massNumber="%s" mass="%s" abundance="%s" />\n' % (isotope, elements[symbol].isotopes[isotope][0], elements[symbol].isotopes[isotope][1])
-        
-        buff += '    </isotopes>\n'
-        buff += '  </element>\n'
-        
-    buff += '</mspyElements>'
+    buff += '</mspyMonomers>'
     
-    # save elements file
-    try:
-        save = file(path, 'w')
-        save.write(buff.encode("utf-8"))
-        save.close()
-        return True
-    except:
-        return False
-# ----
-
-
-def saveAminoacids(path=os.path.join(blocksdir, 'aminoacids.xml')):
-    """Make and save aminoacids XML."""
-    
-    # make aminoacids xml
-    buff = '<?xml version="1.0" encoding="utf-8" ?>\n'
-    buff += '<mspyAminoacids version="1.0">\n'
-    
-    symbols = aminoacids.keys()
-    symbols.sort()
-    for symbol in symbols:
-        buff += '  <aminoacid symbol="%s" name="%s" abbr="%s" formula="%s" />\n' % (aminoacids[symbol].symbol, aminoacids[symbol].name, aminoacids[symbol].abbr, aminoacids[symbol].formula)
-        
-    buff += '</mspyAminoacids>'
-    
-    # save aminoacids file
+    # save monomers file
     try:
         save = file(path, 'w')
         save.write(buff.encode("utf-8"))
@@ -751,34 +632,6 @@ def saveEnzymes(path=os.path.join(blocksdir, 'enzymes.xml')):
 # ----
 
 
-def saveFragments(path=os.path.join(blocksdir, 'fragments.xml')):
-    """Make and save fragments XML."""
-    
-    # make fragments xml
-    buff = '<?xml version="1.0" encoding="utf-8" ?>\n'
-    buff += '<mspyFragments version="1.0">\n'
-    
-    names = fragments.keys()
-    names.sort()
-    for name in names:
-        buff += '  <fragment name="%s" terminus="%s" specifity="%s">\n' % (_escape(fragments[name].name), fragments[name].terminus, fragments[name].specifity)
-        buff += '    <formula nTerm="%s" cTerm="%s" neutralLoss="%s" />\n' % (fragments[name].nTermFormula, fragments[name].cTermFormula, fragments[name].lossFormula)
-        buff += '    <termFilter nTerm="%s" cTerm="%s" />\n' % (int(fragments[name].nTermFilter), int(fragments[name].cTermFilter))
-        buff += '  </fragment>\n'
-        
-    buff += '</mspyFragments>'
-    
-    # save fragments file
-    try:
-        save = file(path, 'w')
-        save.write(buff.encode("utf-8"))
-        save.close()
-        return True
-    except:
-        return False
-# ----
-
-
 def saveModifications(path=os.path.join(blocksdir, 'modifications.xml')):
     """Make and save modifications XML."""
     
