@@ -401,19 +401,23 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             
             # get retention time
             if paramName == 'TimeInMinutes' and paramValue != None:
-                self.data[self.currentID]['retentionTime'] = float(paramValue)*60
+                try: self.data[self.currentID]['retentionTime'] = float(paramValue)*60
+                except ValueError: pass
             
             # get total ion current
             elif paramName == 'TotalIonCurrent' and paramValue != None:
-                self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                try: self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'MassToChargeRatio' and paramValue != None:
-                self.data[self.currentID]['precursorMZ'] = float(paramValue)
+                try: self.data[self.currentID]['precursorMZ'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'ChargeState' and paramValue != None:
-                self.data[self.currentID]['precursorCharge'] = float(paramValue)
+                try: self.data[self.currentID]['precursorCharge'] = int(paramValue)
+                except ValueError: pass
             
             # get polarity
             elif paramName == 'Polarity':
@@ -535,19 +539,23 @@ class scanHandler(xml.sax.handler.ContentHandler):
             
             # get retention time
             if paramName == 'TimeInMinutes' and paramValue != None:
-                self.data['retentionTime'] = float(paramValue)*60
+                try: self.data['retentionTime'] = float(paramValue)*60
+                except ValueError: pass
             
             # get total ion current
             elif paramName == 'TotalIonCurrent' and paramValue != None:
-                self.data['totIonCurrent'] = float(paramValue)
+                try: self.data['totIonCurrent'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'MassToChargeRatio' and paramValue != None:
-                self.data['precursorMZ'] = float(paramValue)
+                try: self.data['precursorMZ'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'ChargeState' and paramValue != None:
-                self.data['precursorCharge'] = float(paramValue)
+                try: self.data['precursorCharge'] = int(paramValue)
+                except ValueError: pass
             
             # get polarity
             elif paramName == 'Polarity':
@@ -714,19 +722,23 @@ class runHandler(xml.sax.handler.ContentHandler):
             
             # get retention time
             if paramName == 'TimeInMinutes' and paramValue != None:
-                self.data[self.currentID]['retentionTime'] = float(paramValue)*60
+                try: self.data[self.currentID]['retentionTime'] = float(paramValue)*60
+                except ValueError: pass
             
             # get total ion current
             elif paramName == 'TotalIonCurrent' and paramValue != None:
-                self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                try: self.data[self.currentID]['totIonCurrent'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'MassToChargeRatio' and paramValue != None:
-                self.data[self.currentID]['precursorMZ'] = float(paramValue)
+                try: self.data[self.currentID]['precursorMZ'] = float(paramValue)
+                except ValueError: pass
             
             # get precursor m/z
             elif paramName == 'ChargeState' and paramValue != None:
-                self.data[self.currentID]['precursorCharge'] = float(paramValue)
+                try: self.data[self.currentID]['precursorCharge'] = int(paramValue)
+                except ValueError: pass
             
             # get polarity
             elif paramName == 'Polarity':
