@@ -21,10 +21,11 @@ import base64
 import zlib
 import struct
 import os.path
+import numpy
 from copy import deepcopy
 
-# load configuration
-import config
+# load stopper
+from stopper import CHECK_FORCE_QUIT
 
 # register essential objects
 import objects
@@ -40,15 +41,7 @@ class parseMZML():
         self.path = path
         self._scans = None
         self._scanlist = None
-        self._info = {
-            'title': '',
-            'operator': '',
-            'contact': '',
-            'institution': '',
-            'date': '',
-            'instrument': '',
-            'notes': '',
-        }
+        self._info = None
         
         # check path
         if not os.path.exists(path):
@@ -106,7 +99,7 @@ class parseMZML():
         except stopParsing:
             self._info = handler.data
         except xml.sax.SAXException:
-            pass
+            self._info = False
         
         return self._info
     # ----
@@ -137,7 +130,7 @@ class parseMZML():
     # ----
     
     
-    def getScan(self, scanID=None, raw=False):
+    def getScan(self, scanID=None):
         """Get spectrum from document."""
         
         # use preloaded data if available
@@ -163,11 +156,8 @@ class parseMZML():
         if not data:
             return False
         
-        # return data
-        if raw:
-            return data
-        else:
-            return self._makeScan(data)
+        # return scan
+        return self._makeScan(data)
     # ----
     
     
@@ -184,6 +174,7 @@ class parseMZML():
             scan = objects.scan(points=points)
         
         # set metadata
+        scan.title = scanData['title']
         scan.scanNumber = scanData['scanNumber']
         scan.parentScanNumber = scanData['parentScanNumber']
         scan.msLevel = scanData['msLevel']
@@ -232,7 +223,15 @@ class parseMZML():
         intData = struct.unpack('<' + intPrecision * count, intData[0:len(intData)])
         
         # format
-        data = map(list, zip(mzData, intData))
+        if scanData['spectrumType'] == 'discrete':
+            data = map(list, zip(mzData, intData))
+        else:
+            mzData = numpy.array(mzData)
+            mzData.shape = (-1,1)
+            intData = numpy.array(intData)
+            intData.shape = (-1,1)
+            data = numpy.concatenate((mzData,intData), axis=1)
+            data = data.copy()
         
         return data
     # ----
@@ -320,6 +319,7 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             self._scanHierarchy.append(self.currentID)
             
             scan = {
+                'title': '',
                 'scanNumber': self.currentID,
                 'parentScanNumber': self._scanHierarchy[-2],
                 'msLevel': None,
@@ -472,6 +472,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
                 self._isMatch = True
                 
                 self.data = {
+                    'title': '',
                     'scanNumber': scanID,
                     'parentScanNumber': self._scanHierarchy[-2],
                     'msLevel': None,
@@ -689,6 +690,7 @@ class runHandler(xml.sax.handler.ContentHandler):
             self._scanHierarchy.append(self.currentID)
             
             scan = {
+                'title': '',
                 'scanNumber': self.currentID,
                 'parentScanNumber': self._scanHierarchy[-2],
                 'msLevel': None,
