@@ -22,15 +22,15 @@ import zlib
 import struct
 import re
 import os.path
+import numpy
 from copy import deepcopy
 
-# load configuration
-import config
+# load stopper
+from stopper import CHECK_FORCE_QUIT
 
 # register essential objects
 import objects
 
-
 # compile basic patterns
 retentionPattern = re.compile('^PT((\d*\.?\d*)M)?((\d*\.?\d*)S)?$')
 
@@ -45,15 +45,7 @@ class parseMZXML():
         self.path = path
         self._scans = None
         self._scanlist = None
-        self._info = {
-            'title': '',
-            'operator': '',
-            'contact': '',
-            'institution': '',
-            'date': '',
-            'instrument': '',
-            'notes': '',
-        }
+        self._info = None
         
         # check path
         if not os.path.exists(path):
@@ -109,7 +101,7 @@ class parseMZXML():
         except stopParsing:
             self._info = handler.data
         except xml.sax.SAXException:
-            pass
+            self._info = False
         
         return self._info
     # ----
@@ -140,7 +132,7 @@ class parseMZXML():
     # ----
     
     
-    def getScan(self, scanID=None, raw=False):
+    def getScan(self, scanID=None):
         """Get spectrum from document."""
         
         # use preloaded data if available
@@ -166,11 +158,8 @@ class parseMZXML():
         if not data:
             return False
         
-        # return data
-        if raw:
-            return data
-        else:
-            return self._makeScan(data)
+        # return scan
+        return self._makeScan(data)
     # ----
     
     
@@ -187,6 +176,7 @@ class parseMZXML():
             scan = objects.scan(points=points)
         
         # set metadata
+        scan.title = scanData['title']
         scan.scanNumber = scanData['scanNumber']
         scan.parentScanNumber = scanData['parentScanNumber']
         scan.msLevel = scanData['msLevel']
@@ -234,7 +224,12 @@ class parseMZXML():
         data = struct.unpack(endian + precision * count, data[0:len(data)])
         
         # format
-        data = map(list, zip(data[::2], data[1::2]))
+        if scanData['spectrumType'] == 'discrete':
+            data = map(list, zip(data[::2], data[1::2]))
+        else:
+            data = numpy.array(data)
+            data.shape = (-1,2)
+            data = data.copy()
         
         return data
     # ----
@@ -316,6 +311,7 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             self._scanHierarchy.append(self.currentID)
             
             scan = {
+                'title': '',
                 'scanNumber': self.currentID,
                 'parentScanNumber': self._scanHierarchy[-2],
                 'msLevel': None,
@@ -495,6 +491,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
                 self._isMatch = True
                 
                 self.data = {
+                    'title': '',
                     'scanNumber': scanID,
                     'parentScanNumber': self._scanHierarchy[-2],
                     'msLevel': None,
@@ -703,6 +700,7 @@ class runHandler(xml.sax.handler.ContentHandler):
             self._scanHierarchy.append(self.currentID)
             
             scan = {
+                'title': '',
                 'scanNumber': self.currentID,
                 'parentScanNumber': self._scanHierarchy[-2],
                 'msLevel': None,
