@@ -16,6 +16,7 @@
 # -------------------------------------------------------------------------
 
 
-# register objects
+# register objects and modules
 from objects import *
 from canvas import *
+from viewer import viewer
\ No newline at end of file
