@@ -69,6 +69,7 @@ class canvas(wx.Panel):
             'yScaleFactor': 0.1,
             'maxZoom': 0.001,
             'checkLimits': True,
+            'reverseScrolling': False,
             'reverseDrawing': False,
             'canvasColour': (255, 255, 255),
             'plotColour': (255, 255, 255),
@@ -162,7 +163,10 @@ class canvas(wx.Panel):
                 minX = rangeXmin
             if maxX > rangeXmax:
                 maxX = rangeXmax
-                
+            if minX > maxX:
+                minX = rangeXmin
+                maxX = rangeXmax
+            
             # draw plot
             self.draw(self.lastDraw[0], (minX, maxX), (minY, maxY))
         else:
@@ -549,13 +553,15 @@ class canvas(wx.Panel):
         direction = 1
         if evt.GetWheelRotation() < 0:
             direction = -1
+        if self.properties['reverseScrolling']:
+            direction *= -1
         
         # set new charge and count for isotope ruler
         if self.mouseFce == 'isotoperuler' and evt.ShiftDown():
             if evt.AltDown() or evt.ControlDown():
-                self.currentIsotopeLines = min(50, self.currentIsotopeLines + 1*direction)
+                self.currentIsotopeLines = min(50, self.currentIsotopeLines + direction)
             else:
-                self.currentCharge = max(1, self.currentCharge + 1*direction)
+                self.currentCharge = max(1, self.currentCharge + direction)
                 self.currentCharge = min(50, self.currentCharge)
             self.drawMouseTracker()
             return
@@ -1466,7 +1472,7 @@ class canvas(wx.Panel):
             xFormat = '%0.'+`self.properties['xPosDigits']`+'f'
             yFormat = '%0.'+`self.properties['yPosDigits']`+'f'
             xText = xFormat % (self.cursorPosition[0])
-            if self.cursorPosition[1] > 10000:
+            if abs(self.cursorPosition[1]) > 10000:
                 yFormat = '%.2e'
             yText = yFormat % (self.cursorPosition[1])
             
