@@ -871,7 +871,7 @@ class points:
         # draw points
         if self.properties['showPoints']:
             pencolour = [max(x-70,0) for x in self.properties['pointColour']]
-            pen = wx.Pen(pencolour, 1*printerScale['drawings'], wx.SOLID)
+            pen = wx.Pen(pencolour, self.properties['lineWidth']*printerScale['drawings'], wx.SOLID)
             brush = wx.Brush(self.properties['pointColour'], wx.SOLID)
             dc.SetPen(pen)
             dc.SetBrush(brush)
@@ -1725,7 +1725,7 @@ def _interpolateLine(p1, p2, x=None, y=None):
 
 
 def _getIndex(points, x):
-    """Get nearest index for selected point."""
+    """Get nearest lower index for selected point."""
     
     lo = 0
     hi = len(points)
