@@ -57,14 +57,15 @@ class viewerFrame(wx.Frame):
         ]
         
         # init plot canvas
-        self.plotCanvas = canvas.canvas(self, size=(700,400), \
-            xLabel='m/z', \
-            yLabel='a.i.', \
-            showPosBar=True, \
-            showIntBar=True, \
-            posBarHeight=6, \
-            intBarHeight=6, \
-            xPosDigits=4, \
+        self.plotCanvas = canvas.canvas(self,
+            size = (700,400),
+            xLabel = 'm/z',
+            yLabel = 'a.i.',
+            showPosBar = True,
+            showIntBar = True,
+            posBarHeight = 6,
+            intBarHeight = 6,
+            xPosDigits = 4
         )
         self.plotCanvas.setProperties(**attr)
         self.plotCanvas.setMFunction('cross')
@@ -75,7 +76,11 @@ class viewerFrame(wx.Frame):
         
         # append data sets
         for x, item in enumerate(data):
-            if isinstance(item, mspy.scan):
+            if isinstance(item, mspy.plot.points):
+                obj = item
+            elif isinstance(item, mspy.plot.spectrum):
+                obj = item
+            elif isinstance(item, mspy.scan):
                 obj = objects.spectrum(item)
             else:
                 obj = objects.points(item)
